@@ -11,13 +11,12 @@
 
 #include <stdlib.h>
 
-#include "odemilbutton.h"
-#include "odscrolledbox.h"
-
 #include "cmdseq.h"
 #include "menus.h"
+#include "odmultibutton.h"
 #include "strutil.h"
 #include "xmlutil.h"
+
 #include "buttons.h"
 
 /* ----------------------------------------------------------------------------------------- */
@@ -35,10 +34,10 @@ typedef struct {
 } BColor;
 
 struct Button {				/* A run-time button definition, as stored in button banks. */
-	gchar	label[BTN_FACES][BTN_LABEL_SIZE];	/* Text to label button with. */
+	gchar	label[BTN_FACES][BTN_LABEL_SIZE];	/* User-visible text to label button with. */
 	GString	*cmdseq[BTN_FACES];			/* Command sequence to run when clicked. */
 	gchar	key[BTN_FACES][KEY_NAME_SIZE];		/* Keyboard shortcut. */
-	BColor	color[BTN_FACES][2];			/* Back- and fore colors for each face. */
+	BColor	color[BTN_FACES][2];			/* Back- and foreground colors for each face. */
 	gchar	menu[MNU_MENU_NAME_SIZE];		/* Name of menu bound to this button. */
 	gchar	tooltip[BTN_TOOLTIP_SIZE];		/* Tooltip (help text) for this button. */
 	guint32	flags;					/* Various flags. See BTF_XXX defines in header. */
@@ -496,43 +495,6 @@ void btn_button_set_color_fg_widget(GtkWidget *widget, BtnFace face, const GdkCo
 	}
 }
 
-/* 2000-12-11 -	Set the menu for a button. */
-void btn_button_set_menu(Button *btn, const gchar *name)
-{
-	if(btn != NULL)
-		stu_strncpy(btn->menu, name, sizeof btn->menu);
-}
-
-void btn_button_set_menu_widget(GtkWidget *wid, const gchar *menu)
-{
-	Button	*btn = btn_button_get(wid);
-
-	if(btn != NULL)
-	{
-		od_emil_button_remove_menu(OD_EMIL_BUTTON(wid));
-		if(menu == NULL || *menu == '\0')	/* Remove? */
-			btn_button_set_menu(btn, "");
-		else
-		{
-			MainInfo	*min;
-			GtkWidget	*m;
-
-			btn_button_set_menu(btn, menu);
-			min = gtk_object_get_data(GTK_OBJECT(wid), "min");
-			if((m = mnu_menu_widget_get(min->cfg.menus, menu)) != NULL)
-				od_emil_button_set_menu(OD_EMIL_BUTTON(wid), GTK_MENU(m));
-		}
-	}
-}
-
-/* 2000-12-11 -	Return the menu for a button. */
-const gchar * btn_button_get_menu(const Button *btn)
-{
-	if(btn != NULL)
-		return btn->menu;
-	return NULL;
-}
-
 /* 1999-05-01 -	Get the definition from an instantiated widget. */
 Button * btn_button_get(GtkWidget *wid)
 {
@@ -572,7 +534,7 @@ gboolean btn_button_get_color_bg(Button *btn, BtnFace face, GdkColor *bg)
 {
 	if((btn != NULL) && (bg != NULL))
 	{
-		if(btn->color[face][0].valid == TRUE)
+		if(btn->color[face][0].valid)
 		{
 			*bg = btn->color[face][0].color;
 			return TRUE;
@@ -589,7 +551,7 @@ gboolean btn_button_get_color_fg(Button *btn, BtnFace face, GdkColor *fg)
 {
 	if((btn != NULL) && (fg != NULL))
 	{
-		if(btn->color[face][1].valid == TRUE)
+		if(btn->color[face][1].valid)
 		{
 			*fg = btn->color[face][1].color;
 			return TRUE;
@@ -682,7 +644,6 @@ void btn_button_clear(Button *btn)
 		btn->color[i][0].valid = FALSE;		/* Invalidate back- and foreground colors. */
 		btn->color[i][1].valid = FALSE;
 	}
-	btn_button_set_menu(btn, "");
 	btn_button_set_tooltip(btn, NULL);
 	btn->flags = 0U;
 }
@@ -745,11 +706,13 @@ void btn_button_destroy(Button *b)
 /* 1999-05-01 -	This function gets called when the user clicks on an action button, regardless
 **		of which "face" it was. This assumes that MainInfo as passed as last argument
 **		to the btn_buttonsheet_build() call that resulted in the widget.
+** 2004-11-19 -	Ported to use new ODMultiButton.
 */
-static void evt_button_clicked(GtkWidget *wid, gpointer wuser, guint face, gpointer suser)
+static void evt_button_clicked(GtkWidget *wid, gpointer user)
 {	
 	Button		*btn;
-	MainInfo	*min = suser;
+	MainInfo	*min = user;
+	guint		face = od_multibutton_get_index(OD_MULTIBUTTON(wid));
 
 	btn = gtk_object_get_data(GTK_OBJECT(wid), "button");
 	if((min != NULL) && (btn != NULL) && (btn->cmdseq[face] != NULL))
@@ -765,32 +728,17 @@ static gboolean button_set_face(GtkWidget *widget, BtnFace face)
 	if((widget != NULL) && ((btn = gtk_object_get_data(GTK_OBJECT(widget), "button")) != NULL))
 	{
 		const gchar	*lab;
-		GdkColor	buf[2], *bg = NULL, *fg = NULL;
 
-		od_emil_button_remove_widget(OD_EMIL_BUTTON(widget), face);
 		if((lab = btn_button_get_label(btn, face)) != NULL)
 		{
-			if(btn_button_get_color_bg(btn, face, &buf[0]))
-				bg = &buf[0];
-			if(btn_button_get_color_fg(btn, face, &buf[1]))
-				fg = &buf[1];
-			od_emil_button_set_label(OD_EMIL_BUTTON(widget), face, (gchar *) lab, fg, bg, NULL);
+			GdkColor	bgb, fgb, *bgp = NULL, *fgp = NULL;
 
-			/* Experiment with icons in buttons. */
-/*			{
-				GtkWidget	*hbox, *label, *icon;
-				GdkPixmap	*pmap;
-				GdkBitmap	*mask;
-
-				hbox = gtk_hbox_new(FALSE, 0);
-				pmap = gdk_pixmap_colormap_create_from_xpm(NULL, gtk_widget_get_default_colormap(), &mask, NULL, "/home/emil/data/projects/gentoo-0.11.17/icons/Image.xpm");
-				icon = gtk_pixmap_new(pmap, mask);
-				gtk_box_pack_start(GTK_BOX(hbox), icon, FALSE, FALSE, 0);
-				label = gtk_label_new(lab);
-				gtk_box_pack_start(GTK_BOX(hbox), label, TRUE, TRUE, 0);
-				od_emil_button_set_widget(OD_EMIL_BUTTON(widget), face, hbox, NULL);
-			}
-*/			ret = TRUE;
+			if(btn_button_get_color_bg(btn, face, &bgb))
+				bgp = &bgb;
+			if(btn_button_get_color_fg(btn, face, &fgb))
+				fgp = &fgb;
+			od_multibutton_set_text(OD_MULTIBUTTON(widget), face, lab, bgp, fgp, NULL);
+			ret = TRUE;
 		}
 		gtk_widget_queue_draw(widget);
 	}
@@ -805,10 +753,9 @@ static GtkWidget * button_build(MainInfo *min, Button *btn, gboolean partial, Gt
 {
 	GtkWidget	*but;
 
-	if((but = od_emil_button_new()) != NULL)
+	if((but = od_multibutton_new()) != NULL)
 	{
 		gboolean	set = FALSE;
-		const gchar	*mn;
 		BtnFace		i;
 
 		GTK_WIDGET_UNSET_FLAGS(but, GTK_CAN_FOCUS);
@@ -818,19 +765,9 @@ static GtkWidget * button_build(MainInfo *min, Button *btn, gboolean partial, Gt
 
 		for(i = 0; i < BTN_FACES; i++)
 			set |= button_set_face(but, i);
-		if((mn = btn_button_get_menu(btn)) != NULL)
-		{
-			GtkWidget	*menu;
-
-			if((menu = mnu_menu_widget_get(min->cfg.menus, mn)) != NULL)
-			{
-				fprintf(stderr, "Attaching menu \"%s\" to button \"%s\"\n", mn, btn_button_get_label(btn, 0));
-				od_emil_button_set_menu(OD_EMIL_BUTTON(but), GTK_MENU(menu));
-			}
-		}
-		gtk_signal_connect(GTK_OBJECT(but), "activate", GTK_SIGNAL_FUNC(func), user);
+		g_signal_connect(G_OBJECT(but), "clicked", G_CALLBACK(func), user);
 		if(partial)
-			od_emil_button_config_mode(OD_EMIL_BUTTON(but), TRUE);
+			od_multibutton_set_config(OD_MULTIBUTTON(but), TRUE);
 	}
 	return but;
 }
@@ -902,7 +839,7 @@ static GtkWidget * buttonrow_build(MainInfo *min, ButtonRow *brw, gboolean parti
 		}
 	}
 	if(keep_tt)
-		gtk_signal_connect(GTK_OBJECT(hbox), "destroy", GTK_SIGNAL_FUNC(evt_brow_destroy), tt);
+		g_signal_connect(G_OBJECT(hbox), "destroy", G_CALLBACK(evt_brow_destroy), tt);
 	else if(tt != NULL)
 		gtk_object_destroy(GTK_OBJECT(tt));
 
@@ -992,7 +929,7 @@ void btn_buttonrow_set_width(ButtonRow *brw, guint width)
 				btn_button_destroy(brw->button + i);
 		}
 		brw->button = g_realloc(brw->button, width * sizeof *brw->button);
-		if(width > brw->width)		/* Growing? The init the new ones. */
+		if(width > brw->width)          /* Growing? Then init the new ones. */
 		{
 			for(i = brw->width; i < width; i++)
 			{
@@ -1212,30 +1149,22 @@ static GtkWidget * buttonsheet_build(MainInfo *min, ButtonSheet *bsh, gboolean p
 	if(bsh->rows == NULL)
 		return NULL;
 
-	scbox = od_scrolled_box_new();
-	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scbox), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
-
-	/* FIXME: This isn't exactly pure. Make the Shortcuts sheet the same visible height as the buttons. */
-	if(!partial && strcmp(bsh->label, "Shortcuts") == 0)
-	{
-		ButtonSheet	*def;
-
-		if((def = btn_buttonsheet_get(&min->cfg.buttons, BTN_DEFAULT_SHEET)) != NULL)
-			od_scrolled_box_set_num(OD_SCROLLED_BOX(scbox), def->height);
-	}
-	else
-		od_scrolled_box_set_num(OD_SCROLLED_BOX(scbox), bsh->height);
-
+	/* First, stack all rows in a vbox. */
 	vbox = gtk_vbox_new(FALSE, 0);
 	for(iter = bsh->rows; iter != NULL; iter = g_list_next(iter))
 	{
 		if((row = buttonrow_build(min, iter->data, partial, func, user)) != NULL)
 			gtk_box_pack_start(GTK_BOX(vbox), row, FALSE, FALSE, 0);
 	}
-	gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(scbox), vbox);
-	gtk_widget_show_all(vbox);
-
-	return scbox;
+	/* Next, wrap the Shortcuts in a scrolled window, since the default buttons decide the height. */
+	if(strcmp(bsh->label, "Shortcuts") == 0)
+	{
+		scbox = gtk_scrolled_window_new(NULL, NULL);
+		gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scbox), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
+		gtk_scrolled_window_add_with_viewport(GTK_SCROLLED_WINDOW(scbox), vbox);
+		return scbox;
+	}
+	return vbox;
 }
 
 /* 1998-09-15 -	Build the GTK+ GUI representation of sheet named <label>.
@@ -1244,7 +1173,7 @@ static GtkWidget * buttonsheet_build(MainInfo *min, ButtonSheet *bsh, gboolean p
 */
 GtkWidget * btn_buttonsheet_build(MainInfo *min, ButtonInfo *bti, const gchar *label, gboolean partial, GtkSignalFunc func, gpointer user)
 {
-	GtkWidget	*sheet;
+	GtkWidget	*sheet = NULL;
 	GList		*iter;
 
 	if(label == NULL)
@@ -1257,12 +1186,11 @@ GtkWidget * btn_buttonsheet_build(MainInfo *min, ButtonInfo *bti, const gchar *l
 	{
 		if(strcmp(((ButtonSheet *) iter->data)->label, label) == 0)
 		{
-			if((sheet = buttonsheet_build(min, iter->data, partial, func, user)) != NULL)
-				return sheet;
+			sheet = buttonsheet_build(min, iter->data, partial, func, user);
 			break;
 		}
 	}
-	return NULL;
+	return sheet;
 }
 
 /* 1999-03-11 -	This gets called once for every widget in a row. If the widget is indeed a
@@ -1278,7 +1206,7 @@ static void btn_callback(GtkWidget *wid, gpointer user)
 	Button		*btn;
 	MainInfo	*min = user;
 
-	if(OD_IS_EMIL_BUTTON(wid) && ((btn = gtk_object_get_data(GTK_OBJECT(wid), "button")) != NULL))
+	if(OD_IS_MULTIBUTTON(wid) && ((btn = gtk_object_get_data(GTK_OBJECT(wid), "button")) != NULL))
 	{
 		const gchar	*key, *cmd;
 		guint		i;
@@ -1303,9 +1231,10 @@ static void row_callback(GtkWidget *wid, gpointer user)
 }
 
 /* 1999-03-11 -	Add key entries for buttons *from the GTK+ sheet*! This is kind of complex,
-**		since the structure of the sheet is non-trivial. Basically, it's a scrolled
-**		box, containing a viewport, containing a vbox full of hboxes, full of hboxes,
-**		full of buttons. Geddit?
+**		since the structure of the sheet is non-trivial.
+** 2008-03-01 -	Basically, For the "Shortcuts" sheet, it's a scrolled box, containing a
+**		viewport, containing a vbox full of hboxes, full of hboxes, full of buttons.
+**		For "Default" sheet, it's just a vbox. Simple! 
 */
 void btn_buttonsheet_built_add_keys(MainInfo *min, GtkContainer *sheet, gpointer user)
 {
@@ -1314,8 +1243,9 @@ void btn_buttonsheet_built_add_keys(MainInfo *min, GtkContainer *sheet, gpointer
 	else
 		fprintf(stderr, "**BUTTONS: Can't have non-NULL user pointer for key!\n");
 
-	/* Get the vbox. */
-	sheet = g_list_first(gtk_container_children(GTK_CONTAINER(g_list_first(gtk_container_children(sheet))->data)))->data;
+	/* Only need to dig out across the scrolled window for shortcuts, Default doesn't scroll. */
+	if(GTK_IS_SCROLLED_WINDOW(sheet))
+		sheet = GTK_CONTAINER(gtk_bin_get_child(GTK_BIN(gtk_bin_get_child(GTK_BIN(sheet)))));
 	gtk_container_foreach(sheet, row_callback, user);	/* Visits each hbox. */
 }
 
