@@ -670,7 +670,7 @@ static void evt_col_fg_clicked(GtkWidget *wid, gpointer user)
 */
 static void init_bdef(MainInfo *min, P_Buttons *page, BDef *def, const gchar *lab, BtnFace face)
 {
-	GtkWidget	*table, *label, *btn, *hbox;
+	GtkWidget	*table, *label, *btn, *img, *hbox;
 
 	def->frame = gtk_frame_new(lab);
 	table = gtk_table_new(4, 3, FALSE);
@@ -700,7 +700,10 @@ static void init_bdef(MainInfo *min, P_Buttons *page, BDef *def, const gchar *la
 	gtk_object_set_data(GTK_OBJECT(def->key), "face", GUINT_TO_POINTER(face));
 	g_signal_connect(G_OBJECT(def->key), "key_press_event", G_CALLBACK(evt_key_press), page);
 	gtk_table_attach(GTK_TABLE(table), def->key, 1, 2, 2, 3,  GTK_EXPAND|GTK_FILL,0,0,0);
-	btn = gtk_button_new_with_label(_("Clr"));
+
+	btn = gtk_button_new();
+	img = gtk_image_new_from_stock(GTK_STOCK_CLEAR, GTK_ICON_SIZE_MENU);
+	gtk_button_set_image(GTK_BUTTON(btn), img);
 	gtk_object_set_data(GTK_OBJECT(btn), "face", GUINT_TO_POINTER(face));
 	g_signal_connect(G_OBJECT(btn), "clicked", G_CALLBACK(evt_key_clear_clicked), page);
 	gtk_table_attach(GTK_TABLE(table), btn, 2, 3, 2, 3,  GTK_FILL,0,0,0);
@@ -722,7 +725,7 @@ static void init_bdef(MainInfo *min, P_Buttons *page, BDef *def, const gchar *la
 	gtk_box_pack_start(GTK_BOX(hbox), def->col_fg, TRUE, TRUE, 0);
 
 	gtk_table_attach(GTK_TABLE(table), hbox, 1, 3, 3, 4,  GTK_EXPAND|GTK_FILL,0,0,0);
-	
+
 	gtk_container_add(GTK_CONTAINER(def->frame), table);
 }
 
