@@ -15,6 +15,7 @@
 ** 1999-05-15 -	Rewrote large parts of this file in order to make the two panes have separate GUIs (notebook
 **		pages), and make room for some color config. Also moved code out into the dpformat module.
 ** 2000-07-02 -	Initialized translation, by marking up translatable strings using _() and N().
+** 2009-04-25 -	Rewritten to no longer use GtkCList, since we're playing with the GTK+ 2.0 crowd now.
 */
 
 #include "gentoo.h"
@@ -44,9 +45,11 @@ typedef struct P_DirPane	P_DirPane;
 
 typedef struct {			/* Pane definition widgets. */
 	GtkWidget	*vbox;
-	GtkWidget	*aclist;	/* List showing available content types. */
+	GtkListStore	*astore;	/* Available column types. */
+	GtkWidget	*aview;		/* Tree view showing available content types. */
 
-	GtkWidget	*sclist;	/* List showing selected content. */
+	GtkListStore	*sstore;	/* Selected column types. */
+	GtkWidget	*sview;		/* Tree view for selected content types. */
 	GtkWidget	*sbutton[4];	/* The fun buttons themselves. */
 
 	GtkWidget	*scmenu;	/* Content option menu. */
@@ -71,11 +74,18 @@ typedef struct {			/* Pane definition widgets. */
 	P_DirPane	*page;
 	DPFormat	edit;
 	guint		index;
-	gint		aclist_row;	/* The last row that were clicked in aclist. */
-	gint		sclist_row;	/* Last clicked row in selected content list. */
+	gint		srow;		/* Last clicked row in selected content list. */
 	MainInfo	*min;		/* Handy to have around. */
 } PDef;
 
+enum {
+	CONTENT_COLUMN_TITLE,
+	CONTENT_COLUMN_DESCRIPTION,
+	CONTENT_COLUMN_CONTENT,
+
+	CONTENT_COLUMN_COUNT
+};
+
 typedef struct {
 	GtkWidget	*vbox;
 
@@ -203,18 +213,19 @@ static DPSizeType size_type_from_name(const gchar *name)
 /* 1999-05-15 -	Set the state of the various widgets of <def> according to its 'edit' field. */
 static void set_pane_widgets(PDef *def)
 {
-	const gchar	*row[2];
 	guint		i;
+	GtkTreeIter	iter;
 
-	gtk_clist_freeze(GTK_CLIST(def->sclist));
-	gtk_clist_clear(GTK_CLIST(def->sclist));
+	gtk_list_store_clear(def->sstore);
 	for(i = 0; i < def->edit.num_columns; i++)
 	{
-		row[0] = def->edit.format[i].title;
-		row[1] = dpf_get_content_name(def->edit.format[i].content);
-		gtk_clist_append(GTK_CLIST(def->sclist), (gchar **) row);
+		gtk_list_store_append(def->sstore, &iter);
+		gtk_list_store_set(def->sstore, &iter,
+				CONTENT_COLUMN_TITLE, def->edit.format[i].title,
+				CONTENT_COLUMN_DESCRIPTION, dpf_get_content_name(def->edit.format[i].content),
+				CONTENT_COLUMN_CONTENT, def->edit.format[i].content,
+				-1);
 	}
-	gtk_clist_thaw(GTK_CLIST(def->sclist));
 	for(i = 0; i < sizeof def->sbutton / sizeof def->sbutton[0]; i++)
 		gtk_widget_set_sensitive(def->sbutton[i], FALSE);
 
@@ -234,8 +245,7 @@ static void set_pane_widgets(PDef *def)
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(def->spos[(guint)  def->edit.sbar_pos]), TRUE);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(def->mctrl[(guint) def->edit.ctrl_mode]), TRUE);
 
-	def->aclist_row = -1;
-	def->sclist_row = -1;
+	def->srow = -1;
 }
 
 /* 1999-05-16 -	Set state of color editing widgets to reflect current data. */
@@ -278,29 +288,37 @@ static void set_history_widgets(PHistory *p)
 
 /* ----------------------------------------------------------------------------------------- */
 
-/* 1999-05-15 -	Add a column showing the indicated content to the selected list of <def>. */
-static void add_column(PDef *def, guint content)
+/* 2009-04-24 -	An available-content row was activated, i.e. double-clicked. Add it to the selected list. */
+static void evt_aview_row_activated(GtkWidget *wid, GtkTreePath *path, GtkTreeViewColumn *column, gpointer user)
 {
-	if(def->edit.num_columns < DP_MAX_COLUMNS)		/* Any room for another column? */
+	PDef		*def = user;
+	GtkTreeIter	iter;
+
+	if(def->edit.num_columns >= DP_MAX_COLUMNS)
+		return;
+
+	if(gtk_tree_model_get_iter(GTK_TREE_MODEL(def->astore), &iter, path))
 	{
+		gint		content;
+		GtkTreePath	*sp;
+
+		gtk_tree_model_get(GTK_TREE_MODEL(def->astore), &iter, CONTENT_COLUMN_CONTENT, &content, -1);
 		dpf_set_default_format(&def->edit.format[def->edit.num_columns], (DPContent) content);
+		gtk_list_store_append(def->sstore, &iter);
+		gtk_list_store_set(def->sstore, &iter,
+				CONTENT_COLUMN_TITLE, def->edit.format[def->edit.num_columns].title,
+				CONTENT_COLUMN_DESCRIPTION, dpf_get_content_name((DPContent) content),
+				CONTENT_COLUMN_CONTENT, content,
+				-1);
 		def->edit.num_columns++;
-		set_pane_widgets(def);
-		gtk_clist_select_row(GTK_CLIST(def->sclist), def->edit.num_columns - 1, 0);
-		gtk_clist_moveto(GTK_CLIST(def->sclist), def->edit.num_columns - 1, -1, 1.0, 0.0);
+		/* Select and scroll-to. */
+		gtk_tree_selection_select_iter(gtk_tree_view_get_selection(GTK_TREE_VIEW(def->sview)), &iter);
+		sp = gtk_tree_model_get_path(GTK_TREE_MODEL(def->sstore), &iter);
+		gtk_tree_view_scroll_to_cell(GTK_TREE_VIEW(def->sview), sp, NULL, TRUE, 0.5f, 0.0f);
+		gtk_tree_path_free(sp);
 	}
 }
 
-/* 2008-07-28 -	Rewritten, now listens to a different signal and works a lot cleaner than before. */
-static void evt_aclist_select_row(GtkWidget *clist, gint row, gint column, GdkEventButton *evt, gpointer user)
-{
-	PDef	*def = user;
-
-	if(row == def->aclist_row && evt->type == GDK_2BUTTON_PRESS)
-		add_column(def, row);
-	def->aclist_row = row;
-}
-
 /* ----------------------------------------------------------------------------------------- */
 
 /* 1998-06-24 -	Build the widgets needed to get a content format string. This consists of
@@ -350,7 +368,7 @@ static GtkWidget * add_content_widgets(P_Edit *edit)
 	const DPSizeType stype[] = { DPSIZE_NATIVE, DPSIZE_BYTES, DPSIZE_KILOBYTES,
 				     DPSIZE_MEGABYTES, DPSIZE_GIGABYTES, DPSIZE_SMART };
 	gchar		*tmp = "", tickstr[2] = "?";
-	DpCFmt		*fmt = &edit->def->edit.format[edit->def->sclist_row];
+	DpCFmt		*fmt = &edit->def->edit.format[edit->def->srow];
 	GtkObject	*adj;
 	GtkWidget	*vbox, *frame, *table, *label, *rb, *trb[sizeof stype / sizeof *stype], *sep;
 	ExtraType	type = ET_NONE;
@@ -503,12 +521,14 @@ static gint evt_edit_justification(GtkWidget *wid, gpointer user)
 static void accept_format(P_Edit *edit)
 {
 	const gchar	*nfmt = "";
-	DpCFmt		*fmt = &edit->def->edit.format[edit->def->sclist_row];
+	DpCFmt		*fmt = &edit->def->edit.format[edit->def->srow];
+	GtkTreeIter	iter;
 
 	strcpy(fmt->title, gtk_entry_get_text(GTK_ENTRY(edit->title)));
 	fmt->just = edit->curr_just;
 	fmt->width = (gint) GTK_ADJUSTMENT(edit->wadj)->value;
-	gtk_clist_set_text(GTK_CLIST(edit->def->sclist), edit->def->sclist_row, 0, fmt->title);
+	if(gtk_tree_selection_get_selected(gtk_tree_view_get_selection(GTK_TREE_VIEW(edit->def->sview)), NULL, &iter))
+		gtk_list_store_set(edit->def->sstore, &iter, CONTENT_COLUMN_TITLE, fmt->title, -1);
 
 	/* If the content uses the general numerical formatting entry, get its text. */
 	if(edit->extype == ET_FORMAT)
@@ -583,10 +603,10 @@ static void accept_format(P_Edit *edit)
 **		are available for all content types (type, name, width, justification).
 **		The bottom frame (which may be missing) contains content-specific settings.
 */
-static gint evt_sclist_edit_clicked(GtkWidget *wid, gpointer user)
+static gint evt_sview_edit_clicked(GtkWidget *wid, gpointer user)
 {
 	PDef		*def = user;
-	DpCFmt		*fmt = &def->edit.format[def->sclist_row];
+	DpCFmt		*fmt = &def->edit.format[def->srow];
 	GtkWidget	*vbox, *frame1, *frame2, *table, *algn, *label;
 	const gchar	*lab[]   = { N_("Content"), N_("Title"), N_("Justification"), N_("Width") },
 			*jtext[] = { N_("Left"), N_("Right"), N_("Center"), NULL };
@@ -656,32 +676,39 @@ static gint evt_sclist_edit_clicked(GtkWidget *wid, gpointer user)
 
 /* ----------------------------------------------------------------------------------------- */
 
-/* 1999-05-15 -	User selected a row in the selected clist. Remember which for later. */
-static void evt_sclist_select_row(GtkWidget *wid, gint row, gint column, GdkEventButton *evt, gpointer user)
+/* 2009-04-24 -	Selected content selection changed, update the editing buttons. This is a bit irky. */
+static void evt_sview_selection_changed(GtkTreeSelection *sel, gpointer user)
 {
-	PDef	*def = user;
+	PDef		*def = user;
+	GtkTreeIter	iter;
 
-	gtk_widget_set_sensitive(def->sbutton[0], TRUE);
-	gtk_widget_set_sensitive(def->sbutton[1], TRUE);
-	gtk_widget_set_sensitive(def->sbutton[2], row > 0);
-	gtk_widget_set_sensitive(def->sbutton[3], row < def->edit.num_columns - 1);
-	def->sclist_row = row;
-	if((evt != NULL) && (evt->type == GDK_2BUTTON_PRESS))
-		gtk_signal_emit_by_name(GTK_OBJECT(def->sbutton[0]), "clicked", def);
-}
+	if(gtk_tree_selection_get_selected(sel, NULL, &iter))
+	{
+		GtkTreePath	*path;
 
-/* 1999-05-15 -	The up till now current row in the selected clist was just unselected, so forget about it. */
-static void evt_sclist_unselect_row(GtkWidget *wid, gint row, gint column, GdkEventButton *evt, gpointer user)
-{
-	PDef	*def = user;
+		gtk_widget_set_sensitive(def->sbutton[0], TRUE);
+		gtk_widget_set_sensitive(def->sbutton[1], TRUE);
+		/* We need to dynamically create the GtkTreePath, to get a row index. */
+		if((path = gtk_tree_model_get_path(GTK_TREE_MODEL(def->sstore), &iter)) != NULL)
+		{
+			const gint	*idx = gtk_tree_path_get_indices(path);
 
-	gtk_widget_set_sensitive(def->sbutton[0], FALSE);
-	gtk_widget_set_sensitive(def->sbutton[1], FALSE);
-	gtk_widget_set_sensitive(def->sbutton[2], FALSE);
-	gtk_widget_set_sensitive(def->sbutton[3], FALSE);
-	def->sclist_row = -1;
+			def->srow = *idx;
+			gtk_widget_set_sensitive(def->sbutton[2], def->srow > 0);
+			gtk_widget_set_sensitive(def->sbutton[3], def->srow < def->edit.num_columns - 1);
+			gtk_tree_path_free(path);
+		}
+	}
+	else
+	{
+		gtk_widget_set_sensitive(def->sbutton[0], FALSE);
+		gtk_widget_set_sensitive(def->sbutton[1], FALSE);
+		gtk_widget_set_sensitive(def->sbutton[2], FALSE);
+		gtk_widget_set_sensitive(def->sbutton[3], FALSE);
+	}
 }
 
+#if 0
 /* 2000-02-29 -	Weird leap day! :) Reorder selected content by direct dragging. */
 static void evt_sclist_move_row(GtkWidget *wid, gint arg1, gint arg2, gpointer user)
 {
@@ -709,53 +736,80 @@ static void evt_sclist_move_row(GtkWidget *wid, gint arg1, gint arg2, gpointer u
 	}
 	def->edit.format[arg2] = tmp;
 }
+#endif
 
 /* 1999-05-15 -	User clicked the "Remove" button below selected column list, so kill a column. */
-static void evt_sclist_remove_clicked(GtkWidget *wid, gpointer user)
+static void evt_sview_remove_clicked(GtkWidget *wid, gpointer user)
 {
-	PDef	*def = user;
-	gint	row;
+	PDef		*def = user;
+	GtkTreeIter	iter;
 
-	row = def->sclist_row;
-	if((row >= 0) && (row < def->edit.num_columns) && (def->edit.num_columns > 1))
+	if(gtk_tree_selection_get_selected(gtk_tree_view_get_selection(GTK_TREE_VIEW(def->sview)), NULL, &iter))
 	{
 		guint	i;
 
-		for(i = row; i < def->edit.num_columns - 1; i++)
+		for(i = def->srow; i < def->edit.num_columns - 1; i++)
 			def->edit.format[i] = def->edit.format[i + 1];
 		def->edit.num_columns--;
-		set_pane_widgets(def);
-		gtk_clist_select_row(GTK_CLIST(def->sclist), (row < def->edit.num_columns) ? row : def->edit.num_columns - 1, -1);
+		gtk_list_store_remove(def->sstore, &iter);
 	}
 }
 
-/* 1999-05-15 -	The "up" arrow has been hit. Move the currently selected column. */
-static void evt_sclist_up_clicked(GtkWidget *wid, gpointer user)
+/* 1999-05-15 -	The "up" arrow has been hit. Move the currently selected column.
+** 2009-04-24 -	Pretty much all rewritten, porting to GtkTreeView and friends.
+*/
+static void evt_sview_up_clicked(GtkWidget *wid, gpointer user)
 {
-	PDef	*def = user;
-	gint	row;
+	PDef		*def = user;
+	gint		row = def->srow;
+	GtkTreeIter	iter, prev;
 
-	row = def->sclist_row;
-	if(row > 0)
+	if(gtk_tree_selection_get_selected(gtk_tree_view_get_selection(GTK_TREE_VIEW(def->sview)), NULL, &iter))
 	{
-		gtk_clist_row_move(GTK_CLIST(def->sclist), row, row - 1);
-		gtk_clist_select_row(GTK_CLIST(def->sclist), row - 1, -1);
-		gtk_clist_moveto(GTK_CLIST(def->sclist), row - 1, -1, 0.0, 0.0);
+		gchar	pstr[8];
+
+		g_snprintf(pstr, sizeof pstr, "%d", row - 1);
+		if(gtk_tree_model_get_iter_from_string(GTK_TREE_MODEL(def->sstore), &prev, pstr))
+		{
+			DpCFmt	tmp;
+
+			gtk_list_store_swap(def->sstore, &iter, &prev);
+			gtk_tree_selection_unselect_all(gtk_tree_view_get_selection(GTK_TREE_VIEW(def->sview)));
+			gtk_tree_selection_select_iter(gtk_tree_view_get_selection(GTK_TREE_VIEW(def->sview)), &iter);
+			/* We need to update the real model, too ... Sigh. */
+			tmp = def->edit.format[row - 1];
+			def->edit.format[row - 1] = def->edit.format[row];
+			def->edit.format[row] = tmp;
+		}
 	}
 }
 
-/* 1999-05-15 -	The "down" arrow has been hit. Move the currently selected column. */
-static void evt_sclist_down_clicked(GtkWidget *wid, gpointer user)
+/* 1999-05-15 -	The "down" arrow has been hit. Move the currently selected column.
+** 2009-04-24 -	Pretty much all rewritten, porting to GtkTreeView and friends.
+*/
+static void evt_sview_down_clicked(GtkWidget *wid, gpointer user)
 {
-	PDef	*def = user;
-	gint	row;
+	PDef		*def = user;
+	gint		row = def->srow;
+	GtkTreeIter	iter, next;
 
-	row = def->sclist_row;
-	if((row >= 0) && (row < def->edit.num_columns))
+	if(gtk_tree_selection_get_selected(gtk_tree_view_get_selection(GTK_TREE_VIEW(def->sview)), NULL, &iter))
 	{
-		gtk_clist_row_move(GTK_CLIST(def->sclist), row, row + 1);
-		gtk_clist_select_row(GTK_CLIST(def->sclist), row + 1, -1);
-		gtk_clist_moveto(GTK_CLIST(def->sclist), row + 1, -1, 1.0, 0.0);
+		gchar	pstr[8];
+
+		g_snprintf(pstr, sizeof pstr, "%d", row + 1);
+		if(gtk_tree_model_get_iter_from_string(GTK_TREE_MODEL(def->sstore), &next, pstr))
+		{
+			DpCFmt	tmp;
+
+			gtk_list_store_swap(def->sstore, &iter, &next);
+			gtk_tree_selection_unselect_all(gtk_tree_view_get_selection(GTK_TREE_VIEW(def->sview)));
+			gtk_tree_selection_select_iter(gtk_tree_view_get_selection(GTK_TREE_VIEW(def->sview)), &iter);
+			/* We need to update the real model, too ... Sigh. */
+			tmp = def->edit.format[row + 1];
+			def->edit.format[row + 1] = def->edit.format[row];
+			def->edit.format[row] = tmp;
+		}
 	}
 }
 
@@ -918,6 +972,52 @@ static void evt_swap_clicked(GtkWidget *wid, gpointer user)
 
 /* ----------------------------------------------------------------------------------------- */
 
+/* 2009-04-24 -	Create a list store suitable for dirpane content columns. */
+static GtkListStore * init_content_list_store(gboolean populate)
+{
+	GtkListStore	*store;
+
+	store = gtk_list_store_new(CONTENT_COLUMN_COUNT, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_INT);
+	if(store != NULL && populate)
+	{
+		GtkTreeIter	iter;
+		guint		i;
+
+		for(i = 0; i < DPC_NUM_TYPES; i++)
+		{
+			gtk_list_store_append(store, &iter);
+			gtk_list_store_set(store, &iter,
+						CONTENT_COLUMN_TITLE, dpf_get_content_title((DPContent) i),
+						CONTENT_COLUMN_DESCRIPTION, dpf_get_content_name((DPContent) i),
+						CONTENT_COLUMN_CONTENT, i,
+						-1);
+		}
+	}
+	return store;
+}
+
+/* 2009-04-24 -	Create a GtkTreeView suitable for displaying a bunch of column content rows. */
+static GtkWidget * init_content_list_view(GtkListStore *store, gboolean available)
+{
+	gchar		*atitle[] = { N_("Default Title"), N_("Content") },
+			*stitle[] = { N_("Title"), N_("Content") }, **title;
+	GtkWidget	*wid;
+	GtkCellRenderer	*cr;
+	GtkTreeViewColumn *vc;
+
+	wid = gtk_tree_view_new_with_model(GTK_TREE_MODEL(store));
+	gtk_tree_selection_set_mode(gtk_tree_view_get_selection(GTK_TREE_VIEW(wid)), GTK_SELECTION_BROWSE);
+	cr = gtk_cell_renderer_text_new();
+	title = available ? atitle : stitle;
+	vc = gtk_tree_view_column_new_with_attributes(_(title[0]), cr, "text", CONTENT_COLUMN_TITLE, NULL);
+	gtk_tree_view_append_column(GTK_TREE_VIEW(wid), vc);
+	vc = gtk_tree_view_column_new_with_attributes(_(title[1]), cr, "text", CONTENT_COLUMN_DESCRIPTION, NULL);
+	gtk_tree_view_append_column(GTK_TREE_VIEW(wid), vc);
+	gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(wid), TRUE);
+
+ 	return wid;
+}
+
 /* 1999-05-15 -	Initialize widgets for configuring a pane. This function is horribly long,
 **		but conceptually very simple: it just builds widgets.
 */
@@ -925,18 +1025,18 @@ static void init_pane_page(P_DirPane *page, guint index, const gchar *other)
 {
 	PDef		*def;
 	GtkWidget	*label, *scwin, *vbox, *frame, *hbox, *table, *button, *sep, *menu;
-	gchar		*atitle[] = { N_("Default Title"), N_("Content") },
-				*stitle[] = { N_("Title"), N_("Content") }, buf[64];
 	const gchar	*smitem[] = { N_("Directories First"), N_("Directories Last"), N_("Directories Mixed"), NULL },
 				*spos[] = { N_("System Default"), N_("Left of List"), N_("Right of List") },
 				*mctrl[] = { N_("System Default"), N_("Always Set"), "(Always Clear)", N_("Toggle") },
 				*tfmt[] = { N_("Copy To %s"), N_("Copy From %s"), N_("Swap With %s") };
-	gchar		*row[2];
+	gchar		buf[64];
 	guint		i;
-	GtkSignalFunc	scfunc[] = { GTK_SIGNAL_FUNC(evt_sclist_edit_clicked), GTK_SIGNAL_FUNC(evt_sclist_remove_clicked),
-								 GTK_SIGNAL_FUNC(evt_sclist_up_clicked), GTK_SIGNAL_FUNC(evt_sclist_down_clicked) },
-				     tool[] = { GTK_SIGNAL_FUNC(evt_copyto_clicked), GTK_SIGNAL_FUNC(evt_copyfrom_clicked),
-				    		    GTK_SIGNAL_FUNC(evt_swap_clicked) };
+	GCallback	scfunc[] = { G_CALLBACK(evt_sview_edit_clicked),
+					G_CALLBACK(evt_sview_remove_clicked),
+					G_CALLBACK(evt_sview_up_clicked),
+					G_CALLBACK(evt_sview_down_clicked) };
+	GtkSignalFunc	tool[] = { GTK_SIGNAL_FUNC(evt_copyto_clicked), GTK_SIGNAL_FUNC(evt_copyfrom_clicked),
+			    GTK_SIGNAL_FUNC(evt_swap_clicked) };
 
 	def = &page->pane[index];
 	def->page  = page;
@@ -952,21 +1052,12 @@ static void init_pane_page(P_DirPane *page, guint index, const gchar *other)
 	vbox = gtk_vbox_new(FALSE, 0);
 	label = gtk_label_new(_("Available Content Types"));
 	gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, FALSE, 0);
+	def->astore = init_content_list_store(TRUE);
+	def->aview = init_content_list_view(def->astore, TRUE);
+	g_signal_connect(G_OBJECT(def->aview), "row_activated", G_CALLBACK(evt_aview_row_activated), def);
 	scwin = gtk_scrolled_window_new(NULL, NULL);
 	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scwin), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-	for(i = 0; i < sizeof atitle / sizeof atitle[0]; i++)
-		atitle[i] = _(atitle[i]);
-	def->aclist = gtk_clist_new_with_titles(2, atitle);
-	g_signal_connect(G_OBJECT(def->aclist), "select_row", G_CALLBACK(evt_aclist_select_row), def);
-	gtk_clist_set_column_width(GTK_CLIST(def->aclist), 0, 70);
-	gtk_clist_column_titles_passive(GTK_CLIST(def->aclist));
-	for(i = 0; i < DPC_NUM_TYPES; i++)
-	{
-		row[0] = (gchar *) dpf_get_content_title((DPContent) i);
-		row[1] = (gchar *) dpf_get_content_name((DPContent) i);
-		gtk_clist_append(GTK_CLIST(def->aclist), row);
-	}
-	gtk_container_add(GTK_CONTAINER(scwin), def->aclist);
+	gtk_container_add(GTK_CONTAINER(scwin), def->aview);
 	gtk_box_pack_start(GTK_BOX(vbox), scwin, TRUE, TRUE, 0);
 	gtk_box_pack_start(GTK_BOX(hbox), vbox, TRUE, TRUE, 0);
 
@@ -978,18 +1069,13 @@ static void init_pane_page(P_DirPane *page, guint index, const gchar *other)
 	vbox = gtk_vbox_new(FALSE, 0);
 	label = gtk_label_new(_("Selected Content Types"));
 	gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, FALSE, 0);
+	def->sstore = init_content_list_store(FALSE);
+	def->sview = init_content_list_view(def->sstore, FALSE);
+	gtk_tree_selection_set_mode(GTK_TREE_SELECTION(gtk_tree_view_get_selection(GTK_TREE_VIEW(def->sview))), GTK_SELECTION_SINGLE);
+	g_signal_connect(G_OBJECT(gtk_tree_view_get_selection(GTK_TREE_VIEW(def->sview))), "changed", G_CALLBACK(evt_sview_selection_changed), def);
 	scwin = gtk_scrolled_window_new(NULL, NULL);
 	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scwin), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-	for(i = 0; i < sizeof stitle / sizeof stitle[0]; i++)
-		stitle[i] = _(stitle[i]);
-	def->sclist = gtk_clist_new_with_titles(2, stitle);
-	g_signal_connect(G_OBJECT(def->sclist), "select_row", G_CALLBACK(evt_sclist_select_row), def);
-	g_signal_connect(G_OBJECT(def->sclist), "unselect_row", G_CALLBACK(evt_sclist_unselect_row), def);
-	g_signal_connect(G_OBJECT(def->sclist), "row_move", G_CALLBACK(evt_sclist_move_row), def);
-	gtk_clist_set_column_width(GTK_CLIST(def->sclist), 0, 70);
-	gtk_clist_column_titles_passive(GTK_CLIST(def->sclist));
-	gtk_clist_set_reorderable(GTK_CLIST(def->sclist), TRUE);
-	gtk_container_add(GTK_CONTAINER(scwin), def->sclist);
+	gtk_container_add(GTK_CONTAINER(scwin), def->sview);
 	gtk_box_pack_start(GTK_BOX(vbox), scwin, TRUE, TRUE, 0);
 	table = gtk_table_new(1, sizeof def->sbutton / sizeof def->sbutton[0], FALSE);
 	def->sbutton[0] = gtk_button_new_with_label(_("Edit..."));
@@ -1275,28 +1361,12 @@ static GtkWidget * cdp_init(MainInfo *min, gchar **name)
 
 	page->min   = min;
 
-/*	page->vbox = gtk_vbox_new(FALSE, 0);*/
-
-/*	page->notebook = gtk_notebook_new();*/
 	init_pane_page(page, 0, _("Right"));
-/*	gtk_notebook_append_page(GTK_NOTEBOOK(page->notebook), page->pane[0].vbox, gtk_label_new(_("Left")));*/
 	init_pane_page(page, 1, _("Left"));
-/*	gtk_notebook_append_page(GTK_NOTEBOOK(page->notebook), page->pane[1].vbox, gtk_label_new(_("Right")));*/
-
 	init_color_page(page);
-/*	gtk_notebook_append_page(GTK_NOTEBOOK(page->notebook), page->colors.vbox, gtk_label_new(_("Colors")));*/
-
 	init_paning_page(page);
-/*	gtk_notebook_append_page(GTK_NOTEBOOK(page->notebook), page->paning.vbox, gtk_label_new(_("Pane Split")));*/
-
 	init_history_page(page);
-/*	gtk_notebook_append_page(GTK_NOTEBOOK(page->notebook), page->history.vbox, gtk_label_new(_("History")));*/
 
-/*	gtk_box_pack_start(GTK_BOX(page->vbox), page->notebook, TRUE, TRUE, 5);*/
-
-/*	gtk_widget_show_all(page->vbox);
-	return page->vbox;
-*/
 	cfg_tree_level_begin(_("Dir Panes"));
 	cfg_tree_level_append(_("Left"), page->pane[0].vbox);
 	cfg_tree_level_append(_("Right"), page->pane[1].vbox);
