@@ -55,15 +55,23 @@ typedef struct {			/* Visual properties notebook page. */
 
 typedef struct {			/* Action properties notebook page. */
 	GtkWidget	*vbox;
-	GtkWidget	*actions;	/* List of properties in current style (both local and inherited). */
-	GtkWidget	*aname;		/* Entry widget for editing name of an action. */
-	GtkWidget	*acmdseq;	/* Entry for command sequence name. */
-	GtkWidget	*acmdpick;	/* Pick button for cmdseq. */
+	GtkListStore	*store;
+	GtkWidget	*view;
 	GtkWidget	*adel;		/* Delete (or override) command button. */
 } PAction;
 
+enum {
+	ACTION_COLUMN_NAME,
+	ACTION_COLUMN_CMDSEQ,
+	ACTION_COLUMN_ACTION,
+	ACTION_COLUMN_WEIGHT,
+
+	ACTION_COLUMN_COUNT
+};
+
 typedef struct {
 	GtkWidget	*vbox;
+	GuiHandlerGroup	*handlers;	/* Collects editing widgets, for signal blocking. */
 	GtkWidget	*scwin;
 	GtkWidget	*tree;		/* Main style tree widget. */
 	gulong		sig_expand;	/* Signal handler for tree item expansion. */
@@ -122,23 +130,25 @@ static void set_widgets_action(P_Styles *page, Style *stl)
 {
 	GList	*alist;
 
-	gtk_clist_freeze(GTK_CLIST(page->dpaction.actions));
-	gtk_clist_clear(GTK_CLIST(page->dpaction.actions));
+	gtk_list_store_clear(page->dpaction.store);
 	if((alist = stl_style_property_get_actions(stl)) != NULL)
 	{
-		gchar	*rd[2];
-		gint	row;
-		GList	*iter;
+		const GList	*iter;
+		GtkTreeIter	titer;
 
 		for(iter = alist; iter != NULL; iter = g_list_next(iter))
 		{
-			rd[0] = iter->data;
-			rd[1] = (gchar *) stl_style_property_get_action(stl, iter->data);
-			row = gtk_clist_append(GTK_CLIST(page->dpaction.actions), rd);
+			gboolean	ovr = stl_style_property_get_override(stl, iter->data);
+			gtk_list_store_append(page->dpaction.store, &titer);
+			gtk_list_store_set(page->dpaction.store, &titer,
+						ACTION_COLUMN_NAME, iter->data,
+						ACTION_COLUMN_CMDSEQ, stl_style_property_get_action(stl, iter->data),
+						ACTION_COLUMN_ACTION, iter->data,
+						ACTION_COLUMN_WEIGHT, ovr ? PANGO_WEIGHT_BOLD : PANGO_WEIGHT_NORMAL,
+						-1);
 		}
 		g_list_free(alist);
 	}
-	gtk_clist_thaw(GTK_CLIST(page->dpaction.actions));
 }
 
 /* 1999-05-24 -	Set various editing widgets to display <stl>'s details. */
@@ -151,6 +161,8 @@ static void set_widgets(P_Styles *page, Style *stl)
 	if((page == NULL) || (stl == NULL))
 		return;
 
+	gui_handler_group_block(page->handlers);
+
 	gtk_entry_set_text(GTK_ENTRY(page->dname), stl_style_get_name(stl));
 	if((pname = stl_style_get_name(stl_styleinfo_style_get_parent(page->si, stl))) != NULL)
 		gtk_entry_set_text(GTK_ENTRY(page->dparent), pname);
@@ -169,17 +181,13 @@ static void set_widgets(P_Styles *page, Style *stl)
 	set_widgets_action(page, stl);
 	gtk_widget_set_sensitive(page->dvbox, TRUE);
 	gtk_widget_set_sensitive(page->del, stl_styleinfo_style_root(page->si) != stl);
+
+	gui_handler_group_unblock(page->handlers);
 }
 
 /* 1999-05-25 -	Reset action editing widgets. */
 static void reset_widgets_action(P_Styles *page)
 {
-	gtk_clist_unselect_all(GTK_CLIST(page->dpaction.actions));
-	gtk_entry_set_text(GTK_ENTRY(page->dpaction.aname), "");
-	gtk_widget_set_sensitive(page->dpaction.aname, FALSE);
-	gtk_entry_set_text(GTK_ENTRY(page->dpaction.acmdseq), "");
-	gtk_widget_set_sensitive(page->dpaction.acmdseq, FALSE);
-	gtk_widget_set_sensitive(page->dpaction.acmdpick, FALSE);
 	gtk_label_set_text(GTK_LABEL(GTK_BIN(page->dpaction.adel)->child), _("Delete Action"));
 	gtk_widget_set_sensitive(page->dpaction.adel, FALSE);
 }
@@ -410,123 +418,159 @@ static void evt_vprop_edit_clicked(GtkWidget *wid, gpointer user)
 
 /* ----------------------------------------------------------------------------------------- */
 
-/* 1999-05-25 -	Set the label of the action "Delete" button. */
-static void action_set_delete_button(P_Styles *page)
+/* 2009-04-22 -	Set the proper label for the Delete Action button. Depends on override. */
+static gboolean set_aprop_delete_button(P_Styles *page, Style *style)
 {
-	gboolean	unique, or;
-	Style		*style;
-
-	if((style = style_get_selected(page, NULL)) == NULL)
-		return;
+	gboolean		unique, ovr;
 
 	unique = stl_style_property_is_unique(style, page->curr_prop);
-	gtk_label_set_text(GTK_LABEL(GTK_BIN(page->dpaction.adel)->child), unique ? _("Delete Action") :
-				_("Revert to Inherited Command"));
-	or = stl_style_property_get_override(style, page->curr_prop);
-	gtk_entry_set_editable(GTK_ENTRY(page->dpaction.aname), or);
-	gtk_widget_set_sensitive(page->dpaction.adel, or);
+	gtk_label_set_text(GTK_LABEL(GTK_BIN(page->dpaction.adel)->child),
+				unique ? _("Delete Action") : _("Revert to Inherited Command"));
+	ovr = stl_style_property_get_override(style, page->curr_prop);
+	gtk_widget_set_sensitive(page->dpaction.adel, ovr);
+
+	return ovr;
 }
 
-/* 1999-05-25 -	An action property has been selected. Update label on "delete/override" button. */
-static void evt_aprop_selected(GtkWidget *wid, gint row, gint column, GdkEventButton *evt, gpointer user)
+/* 2009-04-22 -	Update widgets when action property selection changes. */
+static void evt_aprop_selection_changed(GtkTreeSelection *sel, gpointer user)
 {
 	P_Styles	*page = user;
 	Style		*style;
-	gchar		*prop;
+	GtkTreeIter	myiter;
 
 	if((style = style_get_selected(page, NULL)) == NULL)
 		return;
-
-	page->curr_prop = NULL;
-	page->curr_arow = -1;
-	gtk_clist_get_text(GTK_CLIST(page->dpaction.actions), row, 0, (gchar **) &prop);
-	gtk_entry_set_text(GTK_ENTRY(page->dpaction.aname), prop);
-	gtk_widget_set_sensitive(page->dpaction.aname, TRUE);
-	gtk_entry_set_text(GTK_ENTRY(page->dpaction.acmdseq), stl_style_property_get_action(style, prop));
-	/* Force execution of cmdseq_changed() before we set curr_prop & curr_arow. */
-	gui_events_flush();
-	gtk_widget_set_sensitive(page->dpaction.acmdseq, TRUE);
-	gtk_widget_set_sensitive(page->dpaction.acmdpick, TRUE);
-	page->curr_prop = prop;
-	page->curr_arow = row;
-	action_set_delete_button(page);
-}
-
-/* 1999-05-25 -	An action was just unselected. Update widgets. */
-static void evt_aprop_unselected(GtkWidget *wid, gint row, gint column, GdkEventButton *evt, gpointer user)
-{
-	P_Styles	*page = user;
-	Style		*style;
-
-	if((style = style_get_selected(page, NULL)) == NULL)
-		return;
-
-	page->curr_prop = NULL;
-	page->curr_arow = -1;
-	reset_widgets_action(page);
-}
-
-/* 2004-02-24 -	Action was renamed. */
-static void evt_aprop_name_changed(GtkWidget *wid, gpointer user)
-{
-	P_Styles	*page = user;
-	Style		*style;
-
-	if((style = style_get_selected(page, NULL)) == NULL)
-		return;
-	if((page->curr_prop != NULL) && (page->curr_arow >= 0))
+	if(gtk_tree_selection_get_selected(gtk_tree_view_get_selection(GTK_TREE_VIEW(page->dpaction.view)), NULL, &myiter))
 	{
-		gchar		*oname;
-		const gchar	*nname;
+		gboolean		ovr;
+		GtkTreeViewColumn	*col;
+		GList			*cellrenderers;
 
-		gtk_clist_get_text(GTK_CLIST(page->dpaction.actions), page->curr_arow, 0, &oname);
-		if((oname != NULL) && (nname = gtk_entry_get_text(GTK_ENTRY(wid))) != NULL)
+		gtk_tree_model_get(GTK_TREE_MODEL(page->dpaction.store), &myiter, ACTION_COLUMN_ACTION, &page->curr_prop, -1);
+
+		ovr = set_aprop_delete_button(page, style);
+		/* Set the name column's editable mode, depending on override. */
+		col = gtk_tree_view_get_column(GTK_TREE_VIEW(page->dpaction.view), 0);
+		cellrenderers = gtk_tree_view_column_get_cell_renderers(col);
+		if(cellrenderers != NULL)
 		{
-			if(stl_style_property_rename(style, oname, nname))	/* Will fail on collision. */
-				gtk_clist_set_text(GTK_CLIST(page->dpaction.actions), page->curr_arow, 0, nname);
+			g_object_set(G_OBJECT(cellrenderers->data), "editable", ovr, NULL);
+			g_list_free(cellrenderers);
 		}
+		/* Make name column bold/normal depending on override. */
+		gtk_list_store_set(page->dpaction.store, &myiter, ACTION_COLUMN_WEIGHT, ovr ? PANGO_WEIGHT_BOLD : PANGO_WEIGHT_NORMAL, -1);
 	}
 }
 
-/* 1999-05-25 -	Command sequence of current action property changed. Register that. */
-static void evt_aprop_cmdseq_changed(GtkWidget *wid, gpointer user)
+/* 2009-04-22 -	An action property name was edited. If the name changed, to the rename by calling the Styles module. */
+static void evt_aprop_name_edited(GtkCellRendererText *cr, gchar *spath, gchar *new_name, gpointer user)
 {
 	P_Styles	*page = user;
-	Style		*style;
+	Style		*stl;
+	GtkTreePath	*path;
+	gchar		*name;
 
-	if((style = style_get_selected(page, NULL)) == NULL)
+	if((stl = style_get_selected(page, NULL)) == NULL)
 		return;
 
-	if((page->curr_prop != NULL) && (page->curr_arow >= 0))
+	if((path = gtk_tree_path_new_from_string(spath)) != NULL)
 	{
-		const gchar	*text;
+		GtkTreeIter	iter;
 
-		if((text = gtk_entry_get_text(GTK_ENTRY(wid))) != NULL)
+		if(gtk_tree_model_get_iter(GTK_TREE_MODEL(page->dpaction.store), &iter, path))
 		{
-			gtk_clist_set_text(GTK_CLIST(page->dpaction.actions), page->curr_arow, 1, text);
-			stl_style_property_set_action(style, page->curr_prop, text);
-			action_set_delete_button(page);
+			gtk_tree_model_get(GTK_TREE_MODEL(page->dpaction.store), &iter,
+						ACTION_COLUMN_NAME, &name,
+						-1);
+			/* Only do the change if the new_name really is new. */
+			if(strcmp(name, new_name) != 0)
+			{
+				if(stl_style_property_rename(stl, name, new_name))
+					set_widgets_action(page, stl);
+			}
+			g_free(name);
+		}
+		gtk_tree_path_free(path);
+	}
+}
+
+/* 2009-04-22 -	User wants to select a command from a dialog, for the current action property's action. */
+static void evt_aprop_cmdseq_pick_activated(GtkWidget *wid, gpointer user)
+{
+	P_Styles	*page = user;
+	const gchar	*cmd;
+
+	if((cmd = csq_dialog_sync_new_wait(page->min, ccs_get_current())) != NULL)
+	{
+		Style	*style;
+		GtkTreeIter	myiter;
+
+		if((style = style_get_selected(page, NULL)) == NULL)
+			return;
+		if(gtk_tree_selection_get_selected(gtk_tree_view_get_selection(GTK_TREE_VIEW(page->dpaction.view)), NULL, &myiter))
+		{
+			gtk_tree_model_get(GTK_TREE_MODEL(page->dpaction.store), &myiter, ACTION_COLUMN_ACTION, &page->curr_prop, -1);
+			stl_style_property_set_action(style, page->curr_prop, cmd);
+			gtk_list_store_set(page->dpaction.store, &myiter, ACTION_COLUMN_CMDSEQ, cmd, -1);
 			page->modified = TRUE;
 		}
 	}
 }
 
-/* 1999-05-25 -	User hit the details (magnifying glass) button to the right of the Command field. Dialog-time. */
-static void evt_aprop_cmdpick_clicked(GtkWidget *wid, gpointer user)
+/* 2009-04-22 -	Populate the action name editing entry's popup menu. This gives us a chance to add a menuitem that
+**		brings up the good old "Select Command" dialog. This used to be done by a magnifying-glass button
+**		to the right of the entry, but now the entry is *in* the GtkTreeView.
+*/
+static void evt_aprop_cmdseq_populate_popup(GtkEntry *entry, GtkMenu *menu, gpointer user)
+{
+	GtkWidget	*wid;
+
+	wid = gtk_image_menu_item_new_with_label(_("Select Command ..."));
+	gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(wid), gtk_image_new_from_stock(GTK_STOCK_FIND, GTK_ICON_SIZE_MENU));
+	g_signal_connect(G_OBJECT(wid), "activate", G_CALLBACK(evt_aprop_cmdseq_pick_activated), user);
+	gtk_menu_shell_append(GTK_MENU_SHELL(menu), wid);
+	gtk_widget_show_all(wid);
+}
+
+/* 2009-04-22 -	This gets called when an action property name editing is started. This is the time to attach a
+**		popup-population handler, which gets called if the user right-clicks the entry.
+*/
+static void evt_aprop_cmdseq_edit_started(GtkCellRenderer *renderer, GtkCellEditable *editable, gchar *spath, gpointer user)
+{
+	/* Magically know that the editable is a GtkEntry, and attach a menu signal handler. */
+	g_signal_connect(G_OBJECT(editable), "populate_popup", G_CALLBACK(evt_aprop_cmdseq_populate_popup), user);
+}
+
+static void evt_aprop_cmdseq_edited(GtkCellRendererText *cr, gchar *spath, gchar *new_cmdseq, gpointer user)
 {
 	P_Styles	*page = user;
-	Style		*style;
+	Style		*stl;
+	GtkTreePath	*path;
+	const gchar	*cmdseq;
 
-	if((style = style_get_selected(page, NULL)) == NULL)
+	if(page->curr_prop == NULL)
 		return;
-
-	if((page->curr_prop != NULL) && (page->curr_arow >= 0))
+	if((stl = style_get_selected(page, NULL)) == NULL)
+		return;
+	if((path = gtk_tree_path_new_from_string(spath)) == NULL)
+		return;
+	/* Only do the change if the new_cmdseq really is new. */
+	cmdseq = stl_style_property_get_action(stl, page->curr_prop);
+	if(strcmp(cmdseq, new_cmdseq) != 0)
 	{
-		const gchar	*cmd;
+		GtkTreeIter	iter;
 
-		if((cmd = csq_dialog_sync_new_wait(page->min, ccs_get_current())) != NULL)
-			gtk_entry_set_text(GTK_ENTRY(page->dpaction.acmdseq), cmd);
+		if(gtk_tree_model_get_iter(GTK_TREE_MODEL(page->dpaction.store), &iter, path))
+		{
+			stl_style_property_set_action(stl, page->curr_prop, new_cmdseq);
+			gtk_list_store_set(page->dpaction.store, &iter, ACTION_COLUMN_CMDSEQ, new_cmdseq, -1);
+			gtk_list_store_set(page->dpaction.store, &iter, ACTION_COLUMN_WEIGHT, PANGO_WEIGHT_BOLD, -1);
+			set_aprop_delete_button(page, stl);
+			page->modified = TRUE;
+		}
 	}
+	gtk_tree_path_free(path);
 }
 
 /* 1999-05-25 -	Add a new action property. Pops up a dialog asking for the name. */
@@ -571,10 +615,9 @@ static void evt_aprop_delete_clicked(GtkWidget *wid, gpointer user)
 	if((style = style_get_selected(page, NULL)) == NULL)
 		return;
 
-	if((page->curr_prop != NULL) && (page->curr_arow >= 0))
+	if((page->curr_prop != NULL))
 	{
 		stl_style_property_remove(style, page->curr_prop);
-		gtk_clist_unselect_all(GTK_CLIST(page->dpaction.actions));
 		set_widgets_action(page, style);
 		reset_widgets_action(page);
 		page->modified = TRUE;
@@ -690,50 +733,34 @@ static void build_pvisual(P_Styles *page)
 /* 1999-05-22 -	Build action property editing widgetry. */
 static void build_paction(P_Styles *page)
 {
-	gchar		*at[] = { N_("Name"), N_("Command") };
 	PAction		*pa = &page->dpaction;
-	GtkWidget	*hbox, *btn, *table, *label, *scwin;
+	GtkWidget	*hbox, *btn, *scwin;
+	GtkCellRenderer	*cr;
+	GtkTreeViewColumn *vc;
 
 	pa->vbox = gtk_vbox_new(FALSE, 0);
+	pa->store = gtk_list_store_new(ACTION_COLUMN_COUNT, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_POINTER, G_TYPE_INT);
+	pa->view = gtk_tree_view_new_with_model(GTK_TREE_MODEL(pa->store));
+	cr = gtk_cell_renderer_text_new();
+	g_object_set(G_OBJECT(cr), "editable", TRUE, NULL);
+	g_signal_connect(G_OBJECT(cr), "edited", G_CALLBACK(evt_aprop_name_edited), page);
+	vc = gtk_tree_view_column_new_with_attributes("(Name)", cr, "text", ACTION_COLUMN_NAME, "weight", ACTION_COLUMN_WEIGHT, NULL);
+	gtk_tree_view_append_column(GTK_TREE_VIEW(pa->view), vc);
+	cr = gtk_cell_renderer_text_new();
+	g_object_set(G_OBJECT(cr), "editable", TRUE, NULL);
+	g_signal_connect(G_OBJECT(cr), "editing_started", G_CALLBACK(evt_aprop_cmdseq_edit_started), page);
+	g_signal_connect(G_OBJECT(cr), "edited", G_CALLBACK(evt_aprop_cmdseq_edited), page);
+	vc = gtk_tree_view_column_new_with_attributes("(CmdSeq)", cr, "text", ACTION_COLUMN_CMDSEQ, NULL);
+	gtk_tree_view_append_column(GTK_TREE_VIEW(pa->view), vc);
+	gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(pa->view), FALSE);
+	g_signal_connect(G_OBJECT(gtk_tree_view_get_selection(GTK_TREE_VIEW(pa->view))), "changed", G_CALLBACK(evt_aprop_selection_changed), page);
 	scwin = gtk_scrolled_window_new(NULL, NULL);
-	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scwin), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
-	pa->actions = gtk_clist_new(2);
-	gtk_clist_set_column_justification(GTK_CLIST(pa->actions), 0, GTK_JUSTIFY_LEFT);
-	gtk_clist_set_column_justification(GTK_CLIST(pa->actions), 1, GTK_JUSTIFY_LEFT);
-	gtk_clist_set_column_auto_resize(GTK_CLIST(pa->actions), 0, TRUE);
-	gtk_clist_set_column_min_width(GTK_CLIST(pa->actions), 0, 128);
-	gtk_clist_set_column_resizeable(GTK_CLIST(pa->actions), 1, FALSE);
-	gtk_clist_append(GTK_CLIST(pa->actions), at);
-	gtk_clist_append(GTK_CLIST(pa->actions), at);
-	gtk_clist_append(GTK_CLIST(pa->actions), at);
-	gtk_clist_append(GTK_CLIST(pa->actions), at);
-	gtk_clist_append(GTK_CLIST(pa->actions), at);
-	gtk_clist_append(GTK_CLIST(pa->actions), at);
-	gtk_clist_append(GTK_CLIST(pa->actions), at);
-	gtk_clist_append(GTK_CLIST(pa->actions), at);
-	g_signal_connect(G_OBJECT(pa->actions), "select_row", G_CALLBACK(evt_aprop_selected), page);
-	g_signal_connect(G_OBJECT(pa->actions), "unselect_row", G_CALLBACK(evt_aprop_unselected), page);
-	gtk_container_add(GTK_CONTAINER(scwin), pa->actions);
+	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scwin), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+	gtk_widget_set_size_request(scwin, -1, 100);
+	gtk_container_add(GTK_CONTAINER(scwin), pa->view);
 	gtk_box_pack_start(GTK_BOX(pa->vbox), scwin, TRUE, TRUE, 0);
 
-	table = gtk_table_new(2, 3, FALSE);
-	label = gtk_label_new(_("Name"));
-	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 0, 1,  0,0,0,0);
-	pa->aname = gtk_entry_new_with_max_length(STL_PROPERTY_NAME_SIZE - 1);
-	gtk_entry_set_editable(GTK_ENTRY(pa->aname), FALSE);
-	g_signal_connect(G_OBJECT(pa->aname), "changed", G_CALLBACK(evt_aprop_name_changed), page);
-	gtk_table_attach(GTK_TABLE(table), pa->aname, 1, 3, 0, 1,  GTK_EXPAND|GTK_FILL,0,0,0);
-	label = gtk_label_new(_("Command"));
-	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 1, 2,  0,0,0,0);
-	pa->acmdseq = gtk_entry_new();
-	g_signal_connect(G_OBJECT(pa->acmdseq), "changed", G_CALLBACK(evt_aprop_cmdseq_changed), page);
-	gtk_table_attach(GTK_TABLE(table), pa->acmdseq, 1, 2, 1, 2,  GTK_EXPAND|GTK_FILL,0,0,0);
-	pa->acmdpick = gui_details_button_new(page->min->gui->window->window);
-	g_signal_connect(G_OBJECT(pa->acmdpick), "clicked", G_CALLBACK(evt_aprop_cmdpick_clicked), page);
-	gtk_table_attach(GTK_TABLE(table), pa->acmdpick, 2, 3, 1, 2,  0,0,0,0);
-	gtk_box_pack_start(GTK_BOX(pa->vbox), table, FALSE, FALSE, 0);
-
-	hbox = gtk_hbox_new(FALSE, 0);
+	hbox = gtk_hbox_new(TRUE, 0);
 	btn = gtk_button_new_with_label(_("Add Action..."));
 	g_signal_connect(G_OBJECT(btn), "clicked", G_CALLBACK(evt_aprop_add_clicked), page);
 	gtk_box_pack_start(GTK_BOX(hbox), btn, TRUE, TRUE, 5);
@@ -757,6 +784,8 @@ static GtkWidget * cst_init(MainInfo *min, gchar **name)
 	page->store = NULL;
 
 	page->vbox = gtk_vbox_new(FALSE, 0);
+	page->handlers = gui_handler_group_new();
+
 	page->scwin = gtk_scrolled_window_new(FALSE, FALSE);
 	page->tree = gtk_tree_view_new();
 	cr = gtk_cell_renderer_text_new();
@@ -776,7 +805,7 @@ static GtkWidget * cst_init(MainInfo *min, gchar **name)
 	label = gtk_label_new(_("Name"));
 	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 0, 1,  0,0,0,0);
 	page->dname = gtk_entry_new_with_max_length(STL_STYLE_NAME_SIZE - 1);
-	g_signal_connect(G_OBJECT(page->dname), "changed", G_CALLBACK(evt_style_name_changed), page);
+	gui_handler_group_connect(page->handlers, G_OBJECT(page->dname), "changed", G_CALLBACK(evt_style_name_changed), page);
 	gtk_table_attach(GTK_TABLE(table), page->dname, 1, 3, 0, 1,  GTK_EXPAND|GTK_FILL,0,0,0);
 	label = gtk_label_new(_("Parent"));
 	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 1, 2,  0,0,0,0);
