@@ -35,12 +35,12 @@ typedef struct {		/* Just a little helper structure for the identification. */
 
 typedef struct {
 	GtkWidget	*vbox;		/* The usual mandatory root vbox. */
+	GuiHandlerGroup	*handlers;	/* Collects editing widgets, for signal blocking. */
 	GtkListStore	*store;		/* Tree model holding existing types. */
 	GtkWidget	*view;		/* Tree view. */
 
 	GtkWidget	*ntable;	/* Table holding the type name widgetry. */
 	GtkWidget	*name;		/* Entry widget for type name. */
-	gint		sig_name;	/* Signal handler number for name changes. */
 
 	GtkWidget	*iframe;	/* Identification frame. */
 	GtkWidget	*itable;	/* This holds all the identification widgets. */
@@ -126,75 +126,77 @@ static void set_widgets(P_Types *page, FType *tpe, GtkTreeIter *iter)
 		igflags[] = { 0, FTFL_NAMEGLOB, FTFL_FILEGLOB },
 		incflags[] = { 0, FTFL_NAMENOCASE, FTFL_FILENOCASE }, i;
 
+	if(tpe == NULL)
+		return;
+
+	/* Block all signal handlers, to ignore the changed-events. */
+	gui_handler_group_block(page->handlers);
+
 	itext[0] = tpe->suffix;
 	itext[1] = tpe->name_re_src;
 	itext[2] = tpe->file_re_src;
 
-	if(tpe != NULL)
+	gtk_entry_set_text(GTK_ENTRY(page->name), tpe->name);
+	gtk_widget_set_sensitive(page->ntable, TRUE);
+
+	for(i = 0; i < 7; i++)
 	{
-		gtk_signal_handler_block(GTK_OBJECT(page->name), page->sig_name);
-		gtk_entry_set_text(GTK_ENTRY(page->name), tpe->name);
-		gtk_signal_handler_unblock(GTK_OBJECT(page->name), page->sig_name);
-		gtk_widget_set_sensitive(page->ntable, TRUE);
-
-		for(i = 0; i < 7; i++)
+		if(page->itmode[GPOINTER_TO_INT(gtk_object_get_user_data(GTK_OBJECT(page->itype[i])))] == tpe->mode)
 		{
-			if(page->itmode[GPOINTER_TO_INT(gtk_object_get_user_data(GTK_OBJECT(page->itype[i])))] == tpe->mode)
-			{
-				gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(page->itype[i]), TRUE);
-				break;
-			}
+			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(page->itype[i]), TRUE);
+			break;
 		}
-
-		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(page->irperm), tpe->flags & FTFL_REQPERM);
-		for(i = 0; i < 6; i++)
-			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(page->iperm[i]), tpe->perm & pflags[i]);
-		gtk_widget_set_sensitive(page->iphbox, tpe->flags & FTFL_REQPERM);
-
-		for(i = 0; i < 3; i++)
-		{
-			gtk_entry_set_text(GTK_ENTRY(page->ident[i].entry), itext[i]);
-			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(page->ident[i].check), tpe->flags & iflags[i]);
-			gtk_widget_set_sensitive(page->ident[i].entry, tpe->flags & iflags[i]);
-			if(i >= 1)
-			{
-				gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(page->ident[i].glob), tpe->flags & igflags[i]);
-				gtk_widget_set_sensitive(page->ident[i].glob, tpe->flags & iflags[i]);
-				gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(page->ident[i].nocase), tpe->flags & incflags[i]);
-				gtk_widget_set_sensitive(page->ident[i].nocase, tpe->flags & iflags[i]);
-			}
-		}
-		gtk_widget_set_sensitive(page->iframe, tpe->mode != 0);
-
-		if(tpe->style != NULL)
-		{
-			GdkPixmap	*ipix;
-			GdkBitmap	*imsk = NULL;
-			gchar		buf[128];
-			const gchar	*iname;
-
-			if((iname = stl_style_property_get_icon(tpe->style, SPN_ICON_UNSEL)) != NULL)
-			{
-				if((ipix = ico_icon_get(page->min, iname, &imsk)) != NULL)
-				{
-					if(page->sicon == NULL)
-					{
-						page->sicon = gtk_pixmap_new(ipix, imsk);
-						gtk_box_pack_start(GTK_BOX(page->sbhbox), page->sicon, FALSE, FALSE, 10);
-						gtk_box_reorder_child(GTK_BOX(page->sbhbox), page->sicon, 0);
-						gtk_widget_show(page->sicon);
-					}
-					else
-						gtk_pixmap_set(GTK_PIXMAP(page->sicon), ipix, imsk);
-				}
-			}
-			g_snprintf(buf, sizeof buf, _("%s - Click to Change..."), stl_style_get_name(tpe->style));
-			gtk_label_set_text(GTK_LABEL(page->slabel), buf);
-		}
-		gtk_widget_set_sensitive(page->sframe, TRUE);
-		gtk_widget_set_sensitive(page->del, tpe->mode != 0);
-		set_movement_widgets(page, iter);
 	}
+
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(page->irperm), tpe->flags & FTFL_REQPERM);
+	for(i = 0; i < 6; i++)
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(page->iperm[i]), tpe->perm & pflags[i]);
+	gtk_widget_set_sensitive(page->iphbox, tpe->flags & FTFL_REQPERM);
+
+	for(i = 0; i < 3; i++)
+	{
+		gtk_entry_set_text(GTK_ENTRY(page->ident[i].entry), itext[i]);
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(page->ident[i].check), tpe->flags & iflags[i]);
+		gtk_widget_set_sensitive(page->ident[i].entry, tpe->flags & iflags[i]);
+		if(i >= 1)
+		{
+			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(page->ident[i].glob), tpe->flags & igflags[i]);
+			gtk_widget_set_sensitive(page->ident[i].glob, tpe->flags & iflags[i]);
+			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(page->ident[i].nocase), tpe->flags & incflags[i]);
+			gtk_widget_set_sensitive(page->ident[i].nocase, tpe->flags & iflags[i]);
+		}
+	}
+	gtk_widget_set_sensitive(page->iframe, tpe->mode != 0);
+
+	if(tpe->style != NULL)
+	{
+		GdkPixmap	*ipix;
+		GdkBitmap	*imsk = NULL;
+		gchar		buf[128];
+		const gchar	*iname;
+
+		if((iname = stl_style_property_get_icon(tpe->style, SPN_ICON_UNSEL)) != NULL)
+		{
+			if((ipix = ico_icon_get(page->min, iname, &imsk)) != NULL)
+			{
+				if(page->sicon == NULL)
+				{
+					page->sicon = gtk_pixmap_new(ipix, imsk);
+					gtk_box_pack_start(GTK_BOX(page->sbhbox), page->sicon, FALSE, FALSE, 10);
+					gtk_box_reorder_child(GTK_BOX(page->sbhbox), page->sicon, 0);
+					gtk_widget_show(page->sicon);
+				}
+				else
+					gtk_pixmap_set(GTK_PIXMAP(page->sicon), ipix, imsk);
+			}
+		}
+		g_snprintf(buf, sizeof buf, _("%s - Click to Change..."), stl_style_get_name(tpe->style));
+		gtk_label_set_text(GTK_LABEL(page->slabel), buf);
+	}
+	gtk_widget_set_sensitive(page->sframe, TRUE);
+	gtk_widget_set_sensitive(page->del, tpe->mode != 0);
+	set_movement_widgets(page, iter);
+	gui_handler_group_unblock(page->handlers);
 }
 
 /* 1998-08-13 -	Reset the state of all the type-editing widgets. */
@@ -657,6 +659,8 @@ static GtkWidget * ctp_init(MainInfo *min, gchar **name)
 
 	page->vbox = gtk_vbox_new(FALSE, 0);
 
+	page->handlers = gui_handler_group_new();
+
 	scwin = gtk_scrolled_window_new(NULL, NULL);
 	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scwin), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 	page->store = gtk_list_store_new(COLUMN_COUNT, G_TYPE_STRING, G_TYPE_POINTER);
@@ -674,7 +678,7 @@ static GtkWidget * ctp_init(MainInfo *min, gchar **name)
 	label = gtk_label_new(_("Name"));
 	gtk_table_attach(GTK_TABLE(page->ntable), label, 0, 1, 0, 1,  GTK_FILL,0,5,0);
 	page->name = gtk_entry_new_with_max_length(STL_STYLE_NAME_SIZE - 1);
-	page->sig_name = g_signal_connect(G_OBJECT(page->name), "changed", G_CALLBACK(evt_name_changed), page);
+	gui_handler_group_connect(page->handlers, G_OBJECT(page->name), "changed", G_CALLBACK(evt_name_changed), page);
 	gtk_table_attach_defaults(GTK_TABLE(page->ntable), page->name, 1, 2, 0, 1);
 
 	gtk_box_pack_start(GTK_BOX(page->vbox), page->ntable, FALSE, FALSE, 0);
@@ -689,21 +693,21 @@ static GtkWidget * ctp_init(MainInfo *min, gchar **name)
 	page->itmode = type;
 	for(i = 0; i < 7; i++)
 	{
-		g_signal_connect(G_OBJECT(page->itype[i]), "clicked", G_CALLBACK(evt_mode_clicked), page);
+		gui_handler_group_connect(page->handlers, G_OBJECT(page->itype[i]), "clicked", G_CALLBACK(evt_mode_clicked), page);
 		gtk_object_set_user_data(GTK_OBJECT(page->itype[i]), GINT_TO_POINTER(i));
 		gtk_box_pack_start(GTK_BOX(page->ithbox), page->itype[i], TRUE, TRUE, 0);
 	}
 	gtk_table_attach(GTK_TABLE(page->itable), page->ithbox, 1, 3, 0, 1, GTK_EXPAND|GTK_FILL,0,0,0);
 
 	page->irperm = gtk_check_button_new_with_label(_("Require Protection"));
-	g_signal_connect(G_OBJECT(page->irperm), "clicked", G_CALLBACK(evt_id_reqperm_clicked), page);
+	gui_handler_group_connect(page->handlers, G_OBJECT(page->irperm), "clicked", G_CALLBACK(evt_id_reqperm_clicked), page);
 	gtk_table_attach(GTK_TABLE(page->itable), page->irperm, 0, 1, 1, 2,  GTK_FILL,0,0,0);
 	page->iphbox = gtk_hbox_new(FALSE, 0);
 	for(i = 0; i < 6; i++)
 	{
 		page->iperm[i] = gtk_toggle_button_new_with_label(_(iplab[i]));
 		gtk_object_set_user_data(GTK_OBJECT(page->iperm[i]), GINT_TO_POINTER(ifperm[i]));
-		g_signal_connect(G_OBJECT(page->iperm[i]), "clicked", G_CALLBACK(evt_id_perm_clicked), page);
+		gui_handler_group_connect(page->handlers, G_OBJECT(page->iperm[i]), "clicked", G_CALLBACK(evt_id_perm_clicked), page);
 		gtk_box_pack_start(GTK_BOX(page->iphbox), page->iperm[i], TRUE, TRUE, 0);
 	}
 	gtk_table_attach(GTK_TABLE(page->itable), page->iphbox, 1, 3, 1, 2,  GTK_EXPAND | GTK_FILL,0,0,0);
@@ -717,12 +721,12 @@ static GtkWidget * ctp_init(MainInfo *min, gchar **name)
 
 		page->ident[i].check = gtk_check_button_new_with_label(_(idlab[i]));
 		gtk_object_set_user_data(GTK_OBJECT(page->ident[i].check), GINT_TO_POINTER(i));
-		g_signal_connect(G_OBJECT(page->ident[i].check), "clicked", G_CALLBACK(evt_id_check_clicked), page);
+		gui_handler_group_connect(page->handlers, G_OBJECT(page->ident[i].check), "clicked", G_CALLBACK(evt_id_check_clicked), page);
 		gtk_table_attach(GTK_TABLE(page->itable), page->ident[i].check, 0, 1, y, y+1,  GTK_FILL,0,0,0);
 
 		page->ident[i].entry = gtk_entry_new_with_max_length(idmax[i] - 1);
 		gtk_object_set_user_data(GTK_OBJECT(page->ident[i].entry), GINT_TO_POINTER(i));
-		g_signal_connect(G_OBJECT(page->ident[i].entry), "changed", G_CALLBACK(evt_id_entry_changed), page);
+		gui_handler_group_connect(page->handlers, G_OBJECT(page->ident[i].entry), "changed", G_CALLBACK(evt_id_entry_changed), page);
 		gtk_table_attach(GTK_TABLE(page->itable), page->ident[i].entry, 1, (i == 0) ? 3 : 2, y, y+1,  GTK_EXPAND | GTK_FILL,0,0,0);
 
 		if(i >= 1)
@@ -732,12 +736,12 @@ static GtkWidget * ctp_init(MainInfo *min, gchar **name)
 			hbox = gtk_hbox_new(FALSE, 0);
 			page->ident[i].glob = gtk_check_button_new_with_label(_("Glob?"));
 			gtk_object_set_user_data(GTK_OBJECT(page->ident[i].glob), GINT_TO_POINTER(i));
-			g_signal_connect(G_OBJECT(page->ident[i].glob), "clicked", G_CALLBACK(evt_id_glob_changed), page);
+			gui_handler_group_connect(page->handlers, G_OBJECT(page->ident[i].glob), "clicked", G_CALLBACK(evt_id_glob_changed), page);
 			gtk_box_pack_start(GTK_BOX(hbox), page->ident[i].glob, FALSE, FALSE, 0);
 
 			page->ident[i].nocase = gtk_check_button_new_with_label(_("Ignore Case?"));
 			gtk_object_set_user_data(GTK_OBJECT(page->ident[i].nocase), GINT_TO_POINTER(i));
-			g_signal_connect(G_OBJECT(page->ident[i].nocase), "clicked", G_CALLBACK(evt_id_nocase_changed), page);
+			gui_handler_group_connect(page->handlers, G_OBJECT(page->ident[i].nocase), "clicked", G_CALLBACK(evt_id_nocase_changed), page);
 			gtk_box_pack_start(GTK_BOX(hbox), page->ident[i].nocase, FALSE, FALSE, 0);
 
 			gtk_table_attach(GTK_TABLE(page->itable), hbox, 2, 3, y, y + 1, GTK_SHRINK,0,0,0);
@@ -751,7 +755,7 @@ static GtkWidget * ctp_init(MainInfo *min, gchar **name)
 	label = gtk_label_new(_("Style"));
 	gtk_box_pack_start(GTK_BOX(page->shbox), label, FALSE, FALSE, 5);
 	page->sbtn = gtk_button_new();
-	g_signal_connect(G_OBJECT(page->sbtn), "clicked", G_CALLBACK(evt_style_clicked), page);
+	gui_handler_group_connect(page->handlers, G_OBJECT(page->sbtn), "clicked", G_CALLBACK(evt_style_clicked), page);
 
 	page->sbhbox = gtk_hbox_new(FALSE, 0);
 	page->sicon  = NULL;
