@@ -21,6 +21,7 @@
 typedef struct {
 	GtkWidget	*vbox;				/* Config page structures always begin like this. */
 	GtkWidget	*content;			/* Content built for us by the window module. */
+	GtkWidget	*border[2];			/* Window border spin buttons. */
 	GtkWidget	*dpos[2];			/* Dialog position mode radio buttons. */
 
 	MainInfo	*min;
@@ -35,15 +36,32 @@ static P_Windows	the_page;
 
 static void populate_page(P_Windows *page)
 {
+	gint	border[2], i;
+
 	if(page->content)
 		gtk_widget_destroy(page->content);
 	page->content = win_wininfo_build(page->edit, &page->modified);
 	gtk_box_pack_start(GTK_BOX(page->vbox), page->content, FALSE, FALSE, 0);
 	gtk_widget_show_all(page->content);
+
+	win_borders_get(page->edit, &border[0], &border[1]);
+	for(i = 0; i < sizeof border / sizeof *border; i++)
+		gtk_spin_button_set_value(GTK_SPIN_BUTTON(page->border[i]), border[i]);
 }
 
 /* ----------------------------------------------------------------------------------------- */
 
+static void evt_border_changed(GtkWidget *wid, gpointer user)
+{
+	P_Windows	*page = user;
+	gint		w, h;
+
+	w = gtk_spin_button_get_value(GTK_SPIN_BUTTON(page->border[0]));
+	h = gtk_spin_button_get_value(GTK_SPIN_BUTTON(page->border[1]));
+	win_borders_set(page->edit, w, h);
+	page->modified = TRUE;
+}
+
 static void evt_dialog_position_toggled(GtkWidget *wid, gpointer user)
 {
 	if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(wid)))
@@ -63,7 +81,8 @@ static void evt_dialog_position_toggled(GtkWidget *wid, gpointer user)
 static GtkWidget * cwn_init(MainInfo *min, gchar **name)
 {
 	P_Windows	*page = &the_page;
-	GtkWidget	*frame, *vbox;
+	GtkWidget	*hbox, *frame, *table, *vbox;
+	const gchar	*blab[] = { N_("Horizontal"), N_("Vertical") };
 	const gchar	*dlab[] = { N_("Dialog Windows Positioned by Window Manager"), N_("Dialog Windows Follow Mouse"), N_("Dialog Windows Center On Screen") };
 	GtkWindowPosition	dpos[] = { GTK_WIN_POS_NONE, GTK_WIN_POS_MOUSE, GTK_WIN_POS_CENTER };
 	guint		i;
@@ -79,20 +98,38 @@ static GtkWidget * cwn_init(MainInfo *min, gchar **name)
 	page->vbox    = gtk_vbox_new(FALSE, 0);
 	page->content = NULL;
 
+	hbox = gtk_hbox_new(FALSE, 0);
+	frame = gtk_frame_new(_("Window Borders"));
+	table = gtk_table_new(2, 2, FALSE);
+	for(i= 0; i < sizeof blab / sizeof *blab; i++)
+	{
+		GtkWidget	*label;
+
+		label = gtk_label_new(_(blab[i]));
+		gtk_table_attach(GTK_TABLE(table), label, 0, 1, i, i + 1, 0,0,0,0);
+		page->border[i] = gtk_spin_button_new_with_range(-32768, 32768, 1);
+		gtk_spin_button_set_digits(GTK_SPIN_BUTTON(page->border[i]), 0);
+		g_signal_connect(G_OBJECT(page->border[i]), "value_changed", G_CALLBACK(evt_border_changed), page);
+		gtk_table_attach(GTK_TABLE(table), page->border[i], 1, 2, i, i + 1, GTK_EXPAND|GTK_FILL,0,0,0);
+	}
+	gtk_container_add(GTK_CONTAINER(frame), table);
+	gtk_box_pack_start(GTK_BOX(hbox), frame, TRUE, TRUE, 0);
+
 	frame = gtk_frame_new(_("Dialog Positioning"));
 	vbox  = gtk_vbox_new(FALSE, 0);
 	for(i = 0; i < sizeof dlab / sizeof *dlab; i++)
 	{
 		page->dpos[i] = gtk_radio_button_new_with_label(group, _(dlab[i]));
 		gtk_object_set_data(GTK_OBJECT(page->dpos[i]), "pos", GINT_TO_POINTER(dpos[i]));
-		gtk_signal_connect(GTK_OBJECT(page->dpos[i]), "toggled", GTK_SIGNAL_FUNC(evt_dialog_position_toggled), page);
+		g_signal_connect(G_OBJECT(page->dpos[i]), "toggled", G_CALLBACK(evt_dialog_position_toggled), page);
 		if(dpos[i] == min->cfg.dialogs.pos)
 			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(page->dpos[i]), TRUE);
 		group = gtk_radio_button_group(GTK_RADIO_BUTTON(page->dpos[i]));
 		gtk_box_pack_start(GTK_BOX(vbox), page->dpos[i], FALSE, FALSE, 0);
 	}
 	gtk_container_add(GTK_CONTAINER(frame), vbox);
-	gtk_box_pack_end(GTK_BOX(page->vbox), frame, TRUE, FALSE, 5);
+	gtk_box_pack_start(GTK_BOX(hbox), frame, TRUE, TRUE, 0);
+	gtk_box_pack_end(GTK_BOX(page->vbox), hbox, TRUE, FALSE, 5);
 
 	gtk_widget_show_all(page->vbox);
 	return page->vbox;
