@@ -11,16 +11,16 @@
 */
 #define	CHD_EXIT_FAILURE	117
 
-gboolean	chd_initialize(MainInfo *min);
+extern gboolean	chd_initialize(MainInfo *min);
 
-void		chd_register(const gchar *prog, pid_t pid, guint32 gflags, guint32 aflags);
+extern void	chd_register(const gchar *prog, pid_t pid, guint32 gflags, guint32 aflags);
 
-void		chd_set_running(CmdSeq *cs, guint index);
-CmdSeq *	chd_get_running(guint *index);
-void		chd_clear_running(void);
-void		chd_clear_lock(void);
+extern void	chd_set_running(CmdSeq *cs, guint index);
+extern CmdSeq *	chd_get_running(guint *index);
+extern void	chd_clear_running(void);
+extern void	chd_clear_lock(void);
 
-void		chd_kill_child(const gchar *name);
-void		chd_kill_children(void);
+extern void	chd_kill_child(const gchar *name);
+extern void	chd_kill_children(void);
 
 #endif		/* CHILDREN_H */
