@@ -9,6 +9,7 @@
 */
 
 #include "gentoo.h"
+#include "convutil.h"
 #include "fileutil.h"
 #include "dirpane.h"
 #include "errors.h"
@@ -45,7 +46,7 @@ static void cpa_copy_body(MainInfo *min, DirPane *src, DirRow *row, gpointer use
 	const gchar	*text;
 	CpaInfo		*cpa = user;
 
-	text = DP_ROW_NAME(row);
+	text = DP_ROW_NAMED(row);
 	if(cpa->action == CPA_COPYAS)
 		g_snprintf(buf, sizeof buf, _("Enter Name for Copy of \"%s\""), text);
 	else
@@ -73,7 +74,7 @@ static void cpa_link_body(MainInfo *min, DirPane *src, DirRow *row, gpointer use
 	const gchar	*text;
 	CpaInfo		*cpa = user;
 
-	text = DP_ROW_NAME(row);
+	text = DP_ROW_NAMED(row);
 	if(cpa->action == CPA_SYMLINKAS)
 		g_snprintf(buf, sizeof buf, _("Enter Name to Link \"%s\" As"), text);
 	else if(cpa->action == CPA_SYMLINKCLONE)
@@ -106,9 +107,10 @@ static const gchar * op_name(CpaAction action)
 /* 1998-09-12 -	Perform action for copy as/clone command. */
 static gint cpa_action(MainInfo *min, DirPane *src, DirPane *dst, DirRow *row, gpointer user)
 {
-	gchar		dest[PATH_MAX], *text;
-	CpaInfo		*cpa = user;
-	OvwRes		ores;
+	const gchar		*text;
+	gchar			dest[PATH_MAX], *file;
+	CpaInfo			*cpa = user;
+	OvwRes			ores;
 
 	if(!fut_cd(src->dir.path, NULL, 0))
 		return 0;
@@ -116,23 +118,31 @@ static gint cpa_action(MainInfo *min, DirPane *src, DirPane *dst, DirRow *row, g
 	text = gtk_entry_get_text(GTK_ENTRY(cpa->entry));
 	if(text && *text)
 	{
+		Conv		conv;
+
+		file = conv_begin(&conv, text);
+
 		/* Enforce difference between clone and copy: clone name is without path. */
 		switch(cpa->action)
 		{
 			case CPA_COPYAS:
 			case CPA_SYMLINKAS:
 				if(strchr(text, G_DIR_SEPARATOR) == NULL)
-					g_snprintf(dest, sizeof dest, "%s%s%s", dst->dir.path, G_DIR_SEPARATOR_S, text);
+					g_snprintf(dest, sizeof dest, "%s%s%s", dst->dir.path, G_DIR_SEPARATOR_S, file);
 				else
-					stu_strncpy(dest, text, sizeof dest);
+					stu_strncpy(dest, file, sizeof dest);
 				break;
 			case CPA_CLONE:
 			case CPA_SYMLINKCLONE:
 				if(strchr(text, G_DIR_SEPARATOR) != NULL)
+				{
+					conv_end(&conv);
 					return 0;
-				g_snprintf(dest, sizeof dest, "%s%s%s", src->dir.path, G_DIR_SEPARATOR_S, text);
+				}
+				g_snprintf(dest, sizeof dest, "%s%s%s", src->dir.path, G_DIR_SEPARATOR_S, file);
 				break;
 		}
+		conv_end(&conv);
 		ores = ovw_overwrite_file(min, dest, dp_full_name(src, DP_ROW_INDEX(src, row)));
 		if(ores == OVW_SKIP)
 			return 1;
