@@ -14,6 +14,7 @@
 #include "cmdseq.h"
 #include "cmdseq_config.h"
 #include "configure.h"
+#include "convutil.h"
 #include "dialog.h"
 #include "dirpane.h"
 #include "errors.h"
@@ -50,21 +51,27 @@ static CmdCfg	*mkdir_cmc = NULL;
 static void make_dir(MkdInfo *mdi)
 {
 	MainInfo	*min = mdi->src->main;
-	gchar		buf[PATH_MAX], *text = gtk_entry_get_text(GTK_ENTRY(mdi->entry));
+	gchar		buf[PATH_MAX], *name;
+	const gchar	*text = gtk_entry_get_text(GTK_ENTRY(mdi->entry));
 	gboolean	doit = FALSE;
 	struct stat	stbuf;
+	Conv		conv;
 
 	if(*text == '\0')				/* Avoid attempting to create "". */
 		return;
-	if(strchr(text, G_DIR_SEPARATOR) != NULL)	/* Also avoid clever paths. */
-		return;
 	if(*mdi->src->dir.path == '\0')			/* Don't blow up in strlen() below. */
 		return;
+	name = conv_begin(&conv, text);
+	if(strchr(name, G_DIR_SEPARATOR) != NULL)	/* Also avoid clever paths. */
+	{
+		conv_end(&conv);
+		return;
+	}
 
 	/* Build destination directory name, taking care to get a single slash between parts. */
 	g_snprintf(buf, sizeof buf, "%s%s%s", mdi->src->dir.path,
 			mdi->src->dir.path[strlen(mdi->src->dir.path) - 1] == G_DIR_SEPARATOR ? "" : G_DIR_SEPARATOR_S,
-			text);
+			name);
 	ovw_overwrite_begin(min, _("\"%s\" Already Exists - Proceed With MkDir?"), 0UL);
 	switch(ovw_overwrite_file(min, buf, NULL))
 	{
@@ -91,8 +98,7 @@ static void make_dir(MkdInfo *mdi)
 		else
 		{
 			dp_rescan(mdi->src);
-			csq_execute_format(min, "DpGotoRow focus=%s nocase=no 're=%s'", mkdir_options.focus_new ? "yes" : "no",
-				gtk_entry_get_text(GTK_ENTRY(mdi->entry)));
+			csq_execute_format(min, "DpGotoRow focus=%s nocase=no 're=%s'", mkdir_options.focus_new ? "yes" : "no", name);
 		}
 	}
 	else
@@ -100,6 +106,7 @@ static void make_dir(MkdInfo *mdi)
 		err_set(min, errno, CMD_ID, buf);
 		err_show(min);
 	}
+	conv_end(&conv);
 	if(mkdir_options.modified)
 		cfg_modified_set(min);
 }
