@@ -11,6 +11,7 @@
 
 #include "cmd_copy.h"
 #include "cmd_delete.h"
+#include "convutil.h"
 #include "dialog.h"
 #include "dirpane.h"
 #include "errors.h"
@@ -68,22 +69,29 @@ gboolean move_dir(MainInfo *min, const gchar *from, const gchar *to)
 	struct stat	stat;
 	gchar		old_dir[PATH_MAX];
 	gchar		dest[PATH_MAX];
+	Conv		conv;
 
 	/* Do safety checking before removing existing destination directory. Bad if nested. */
 	if(fut_is_parent_of(from, to))
 	{
-		gchar	ebuf[2 * PATH_MAX + 128];
+		gchar	ebuf[2 * PATH_MAX + 128], *fromd, *tod;
 
-		g_snprintf(ebuf, sizeof ebuf, _("Can't move directory \"%s\"\nto \"%s\":\nthe source contains the destination."), from, to);
+		fromd = conv_begin_reverse(&conv, from);
+		tod = conv_add_reverse(&conv, to);
+		g_snprintf(ebuf, sizeof ebuf, _("Can't move directory \"%s\"\nto \"%s\":\nthe source contains the destination."), fromd, tod);
 		dlg_dialog_async_new_error(ebuf);
+		conv_end(&conv);
 		return FALSE;
 	}
 	if(fut_is_parent_of(to, from))
 	{
-		gchar	ebuf[2 * PATH_MAX + 128];
+		gchar	ebuf[2 * PATH_MAX + 128], *fromd, *tod;
 
-		g_snprintf(ebuf, sizeof ebuf, _("Can't move directory \"%s\"\nto \"%s\":\nthe destination contains the source."), from, to);
+		fromd = conv_begin_reverse(&conv, from);
+		tod = conv_add_reverse(&conv, to);
+		g_snprintf(ebuf, sizeof ebuf, _("Can't move directory \"%s\"\nto \"%s\":\nthe destination contains the source."), fromd, tod);
 		dlg_dialog_async_new_error(ebuf);
+		conv_end(&conv);
 		return FALSE;
 	}
 
