@@ -4,6 +4,7 @@
 */
 
 #include "gentoo.h"
+#include "convutil.h"
 #include "errors.h"
 #include "fileutil.h"
 #include "overwrite.h"
@@ -30,15 +31,15 @@ typedef struct {
 
 /* ----------------------------------------------------------------------------------------- */
 
-/* 1998-09-12 -	Update body of copy as GUI. */
+/* 1998-09-12 -	Update body of move as GUI. */
 static void mva_body(MainInfo *min, DirPane *src, DirRow *row, gpointer user)
 {
 	gchar	buf[FILENAME_MAX + 32];
 	MvaInfo	*mva = user;
 
-	g_snprintf(buf, sizeof buf, _("Enter Name to Move \"%s\" As"), DP_ROW_NAME(row));
+	g_snprintf(buf, sizeof buf, _("Enter Name to Move \"%s\" As"), DP_ROW_NAMED(row));
 	gtk_label_set_text(GTK_LABEL(mva->label), buf);
-	gtk_entry_set_text(GTK_ENTRY(mva->entry), DP_ROW_NAME(row));
+	gtk_entry_set_text(GTK_ENTRY(mva->entry), DP_ROW_NAMED(row));
 	gtk_entry_select_region(GTK_ENTRY(mva->entry), 0, -1);
 	gtk_widget_grab_focus(mva->entry);
 
@@ -51,7 +52,8 @@ static void mva_body(MainInfo *min, DirPane *src, DirRow *row, gpointer user)
 
 static gint mva_action(MainInfo *min, DirPane *src, DirPane *dst, DirRow *row, gpointer user)
 {
-	gchar		dest[PATH_MAX], *text;
+	gchar		dest[PATH_MAX];
+	const gchar	*text;
 	MvaInfo		*mva = user;
 	gboolean	ret = FALSE;
 
@@ -61,16 +63,21 @@ static gint mva_action(MainInfo *min, DirPane *src, DirPane *dst, DirRow *row, g
 	text = gtk_entry_get_text(GTK_ENTRY(mva->entry));
 	if(text && *text)
 	{
+		Conv	conv;
+		gchar	*file;
+
+		file = conv_begin(&conv, text);
 		if(strchr(text, G_DIR_SEPARATOR) == NULL)
-			g_snprintf(dest, sizeof dest, "%s/%s", dst->dir.path, text);
+			g_snprintf(dest, sizeof dest, "%s/%s", dst->dir.path, file);
 		else
-			stu_strncpy(dest, text, sizeof dest);
+			stu_strncpy(dest, file, sizeof dest);
 		pgs_progress_begin(min, _("Moving As..."), PFLG_COUNT_RECURSIVE | PFLG_ITEM_VISIBLE | PFLG_BYTE_VISIBLE);
 		if(S_ISDIR(DP_ROW_LSTAT(row).st_mode))
 			ret = move_dir(min, DP_ROW_NAME(row), dest);
 		else
 			ret = move_file(min, DP_ROW_NAME(row), dest, &DP_ROW_STAT(row));
 		pgs_progress_end(min);
+		conv_end(&conv);
 	}
 	if(ret)
 		dp_unselect(src, DP_ROW_INDEX(src, row));
