@@ -12,6 +12,7 @@
 
 #include "gentoo.h"
 #include "cmd_delete.h"
+#include "convutil.h"
 #include "errors.h"
 #include "dirpane.h"
 #include "overwrite.h"
@@ -39,7 +40,7 @@ static void ren_body(MainInfo *min, DirPane *src, DirRow *row, gpointer user)
 	const gchar	*name;
 	RenInfo		*ren = user;
 
-	name = DP_ROW_NAME(row);
+	name = DP_ROW_NAMED(row);
 	g_snprintf(temp, sizeof temp, _("Enter New Name For \"%s\""), name);
 	gtk_label_set_text(GTK_LABEL(ren->label), temp);
 	gtk_entry_set_text(GTK_ENTRY(ren->entry), name);
@@ -57,19 +58,22 @@ static gint ren_action(MainInfo *min, DirPane *src, DirPane *dst, DirRow *row, g
 {
 	RenInfo		*ren = user;
 	const gchar	*old_name, *new_name;
+	Conv		conv;
 
 	old_name = DP_ROW_NAME(row);
-	new_name = gtk_entry_get_text(GTK_ENTRY(ren->entry));
+	new_name = conv_begin(&conv, gtk_entry_get_text(GTK_ENTRY(ren->entry)));
 
 	/* Disallow attempts to use rename to move files. */
 	if(strchr(new_name, G_DIR_SEPARATOR))
 	{
 		err_set(min, EINVAL, CMD_ID, old_name);		/* Not quite perfect error message, but simple. */
+		conv_end(&conv);
 		return 0;
 	}
 	if(strcmp(old_name, new_name) == 0)			/* Ignore renames to self. */
 	{
 		dp_unselect(src, DP_ROW_INDEX(src, row));
+		conv_end(&conv);
 		return 1;
 	}
 	/* Check for overwrite, and attempt to clear the way. */
@@ -83,11 +87,17 @@ static gint ren_action(MainInfo *min, DirPane *src, DirPane *dst, DirRow *row, g
 		break;
 	case OVW_PROCEED_FILE:
 		if(!del_delete_file(min, new_name))
+		{
+			conv_end(&conv);
 			return 0;
+		}
 		break;
 	case OVW_PROCEED_DIR:
 		if(!del_delete_dir(min, new_name, FALSE))
+		{
+			conv_end(&conv);
 			return 0;
+		}
 		break;
 	}
 
@@ -96,6 +106,7 @@ static gint ren_action(MainInfo *min, DirPane *src, DirPane *dst, DirRow *row, g
 		err_set(min, errno, CMD_ID, old_name);
 	else
 		dp_unselect(src, DP_ROW_INDEX(src, row));
+	conv_end(&conv);
 	return errno == 0;
 }
 
