@@ -15,6 +15,7 @@
 #include <ctype.h>
 
 #include "cmd_delete.h"
+#include "convutil.h"
 #include "dialog.h"
 #include "dirpane.h"
 #include "errors.h"
@@ -67,7 +68,7 @@ static const gchar * find_tmp_prefix(guint num)
 
 	do
 	{
-		g_snprintf(prefix, sizeof prefix, "gt!%d#%x", round ^ (guint) getpid(), ((guint) time(NULL) % 104729));
+		g_snprintf(prefix, sizeof prefix, "gt!%d#%x", round ^ (guint) getpid(), (guint) time(NULL) % 1007);
 		for(i = 0, found = FALSE; i < num && !found; i++)
 		{
 			g_snprintf(buf, sizeof buf, "%s%u", prefix, i);
@@ -224,6 +225,7 @@ static void init_start(const RenSeqInfo *rsi, GtkWidget *entry)
 static void rsi_update(RenSeqDialog *dlg)
 {
 	GtkWidget	*item;
+	Conv		conv;
 
 	/* First, extract current base so we know how to parse the start index. */
 	item = gtk_menu_get_active(GTK_MENU(gtk_option_menu_get_menu(GTK_OPTION_MENU(dlg->base))));
@@ -235,17 +237,22 @@ static void rsi_update(RenSeqDialog *dlg)
 
 	dlg->rsi->precision = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(dlg->precision));
 
-	g_string_assign(dlg->rsi->head, gtk_entry_get_text(GTK_ENTRY(dlg->head)));
-	g_string_assign(dlg->rsi->tail, gtk_entry_get_text(GTK_ENTRY(dlg->tail)));
+	/* The head and tail need to be converted to filesystem format. */
+	conv_init(&conv);
+	g_string_assign(dlg->rsi->head, conv_begin(&conv, gtk_entry_get_text(GTK_ENTRY(dlg->head))));
+	g_string_assign(dlg->rsi->tail, conv_add(&conv, gtk_entry_get_text(GTK_ENTRY(dlg->tail))));
+	conv_end(&conv);	/* We have copied the filesystem versions, so safe to end the conversion. */
 }
 
 static void preview_update(RenSeqDialog *dlg)
 {
-	const gchar	*name;
+	Conv		conv;
 
+	/* The filename is built in filename encoding, so must be converted back to display. */
+	conv_init(&conv);
 	rsi_update(dlg);
-	name = compute_name(dlg->rsi, 0U);
-	gtk_entry_set_text(GTK_ENTRY(dlg->preview), name);
+	gtk_entry_set_text(GTK_ENTRY(dlg->preview), conv_begin_reverse(&conv, compute_name(dlg->rsi, 0U)));
+	conv_end(&conv);
 }
 
 /* 2001-10-02 -	Joint widget-changed handler. Just call preview_update(). */
@@ -265,7 +272,10 @@ static void evt_guess_clicked(GtkWidget *wid, gpointer user)
 	GString		*head;
 	const gchar	*ptr;
 	guint		prec = 0;
+	Conv		conv;
 
+	/* String processing here is from dlg->name, which is in the filesystem encoding. */
+	conv_init(&conv);
 	head = g_string_new("");
 	for(ptr = dlg->name; *ptr && !isdigit((guchar) *ptr); ptr++)
 		g_string_append_c(head, *ptr);
@@ -273,16 +283,17 @@ static void evt_guess_clicked(GtkWidget *wid, gpointer user)
 	{
 		for(; *ptr && isdigit((guchar) *ptr); prec++, ptr++)
 			;
-		gtk_entry_set_text(GTK_ENTRY(dlg->tail), ptr);
+		gtk_entry_set_text(GTK_ENTRY(dlg->tail), conv_begin_reverse(&conv, ptr));
 	}
 	else if((ptr = strchr(dlg->name, '.')) != NULL)
 	{
 		g_string_truncate(head, ptr - dlg->name);
-		gtk_entry_set_text(GTK_ENTRY(dlg->tail), ptr);
+		gtk_entry_set_text(GTK_ENTRY(dlg->tail), conv_begin_reverse(&conv, ptr));
 	}
-	gtk_entry_set_text(GTK_ENTRY(dlg->head), head->str);
+	gtk_entry_set_text(GTK_ENTRY(dlg->head), conv_add_reverse(&conv, head->str));
 	g_string_free(head, TRUE);
 	gtk_spin_button_set_value(GTK_SPIN_BUTTON(dlg->precision), prec);
+	conv_end(&conv);
 }
 
 /* 2001-10-03 -	Well, here's the actual command entrypoint, like usual. */
@@ -295,6 +306,7 @@ gint cmd_renameseq(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 	RenSeqDialog		dlg;
 	gint			i, ret;
 	GSList			*sel;
+	Conv			conv;
 
 	if((sel = dp_get_selection(src)) == NULL)
 		return 0;
@@ -322,10 +334,10 @@ gint cmd_renameseq(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 	table = gtk_table_new(4, 4, FALSE);
 	label = gtk_label_new(_("Start At"));
 	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 0, 1,  0,0,0,0);
-	adj = gtk_adjustment_new(1.0, 0.0, 4924967295.0, 1.0, 10.0, 10.0);
+	adj = gtk_adjustment_new(1.0, 0.0, 4924967295.0, 1.0, 10.0, 0.0);
 	dlg.start = gtk_spin_button_new(GTK_ADJUSTMENT(adj), 1.0, 0);
 	init_start(&rsi, dlg.start);
-	gtk_signal_connect(GTK_OBJECT(dlg.start), "changed", GTK_SIGNAL_FUNC(evt_something_changed), &dlg);
+	g_signal_connect(G_OBJECT(dlg.start), "changed", G_CALLBACK(evt_something_changed), &dlg);
 	gtk_table_attach(GTK_TABLE(table), dlg.start, 1, 4, 0, 1,  GTK_EXPAND|GTK_FILL,0,0,0);
 
 	label = gtk_label_new(_("Base"));
@@ -335,7 +347,7 @@ gint cmd_renameseq(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 	{
 		bmitem = gtk_menu_item_new_with_label(_(bname[i]));
 		gtk_object_set_data(GTK_OBJECT(bmitem), "index", GINT_TO_POINTER(i));
-		gtk_signal_connect(GTK_OBJECT(bmitem), "activate", GTK_SIGNAL_FUNC(evt_something_changed), &dlg);
+		g_signal_connect(G_OBJECT(bmitem), "activate", G_CALLBACK(evt_something_changed), &dlg);
 		gtk_menu_append(GTK_MENU(bmenu), bmitem);
 		gtk_widget_show(bmitem);
 	}
@@ -346,27 +358,29 @@ gint cmd_renameseq(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 
 	label = gtk_label_new(_("Precision"));
 	gtk_table_attach(GTK_TABLE(table), label, 2, 3, 1, 2,  0,0,0,0);
-	adj   = gtk_adjustment_new(rsi.precision, 0.0, 10.0, 1.0, 1.0, 1.0);
+	adj   = gtk_adjustment_new(rsi.precision, 0.0, 10.0, 1.0, 1.0, 0.0);
 	dlg.precision = gtk_spin_button_new(GTK_ADJUSTMENT(adj), 0, 0);
-	gtk_signal_connect(GTK_OBJECT(adj), "value_changed", GTK_SIGNAL_FUNC(evt_something_changed), &dlg);
+	g_signal_connect(G_OBJECT(adj), "value_changed", G_CALLBACK(evt_something_changed), &dlg);
 	gtk_table_attach(GTK_TABLE(table), dlg.precision, 3, 4, 1, 2,  GTK_EXPAND|GTK_FILL,0,0,0);
 
+	conv_init(&conv);
 	label = gtk_label_new(_("Head"));
 	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 2, 3,  0,0,0,0);
 	dlg.head = gtk_entry_new();
-	gtk_entry_set_text(GTK_ENTRY(dlg.head), rsi.head->str);
-	gtk_signal_connect(GTK_OBJECT(dlg.head), "changed", GTK_SIGNAL_FUNC(evt_something_changed), &dlg);
+	gtk_entry_set_text(GTK_ENTRY(dlg.head), conv_begin_reverse(&conv, rsi.head->str));
+	g_signal_connect(G_OBJECT(dlg.head), "changed", G_CALLBACK(evt_something_changed), &dlg);
 	gtk_table_attach(GTK_TABLE(table), dlg.head, 1, 3, 2, 3,  GTK_EXPAND|GTK_FILL,0,0,0);
 
 	label = gtk_label_new(_("Tail"));
 	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 3, 4,  0,0,0,0);
 	dlg.tail = gtk_entry_new();
-	gtk_entry_set_text(GTK_ENTRY(dlg.tail), rsi.tail->str);
-	gtk_signal_connect(GTK_OBJECT(dlg.tail), "changed", GTK_SIGNAL_FUNC(evt_something_changed), &dlg);
+	gtk_entry_set_text(GTK_ENTRY(dlg.tail), conv_add_reverse(&conv, rsi.tail->str));
+	g_signal_connect(G_OBJECT(dlg.tail), "changed", G_CALLBACK(evt_something_changed), &dlg);
 	gtk_table_attach(GTK_TABLE(table), dlg.tail, 1, 3, 3, 4,  GTK_EXPAND|GTK_FILL,0,0,0);
+	conv_end(&conv);
 
 	dlg.guess = gtk_button_new_with_label(_("Guess"));
-	gtk_signal_connect(GTK_OBJECT(dlg.guess), "clicked", GTK_SIGNAL_FUNC(evt_guess_clicked), &dlg);
+	g_signal_connect(G_OBJECT(dlg.guess), "clicked", G_CALLBACK(evt_guess_clicked), &dlg);
 	gtk_table_attach(GTK_TABLE(table), dlg.guess, 3, 4, 2, 4,  0,GTK_EXPAND|GTK_FILL,0,0);
 
 	label = gtk_label_new(_("Preview"));
