@@ -37,7 +37,6 @@
 #include "events.h"
 #include "fileutil.h"
 #include "guiutil.h"
-#include "miscutil.h"
 #include "strutil.h"
 #include "types.h"
 
@@ -447,7 +446,7 @@ static void selparam_get_value_pointers(guint **ptr, SelParam *sp)
 	ptr[0] = &sp->set;
 	ptr[1] = &sp->type;
 	ptr[2] = &sp->action;
-	ptr[3] = &sp->content;
+	ptr[3] = (guint *) &sp->content;
 }
 
 static void selparam_read_menus(guint **ptr, GtkWidget *opt_menu[])
@@ -503,7 +502,7 @@ gint cmd_selectre(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 		mptr[0] = &sp.basic.set;
 		mptr[1] = &sp.basic.type;
 		mptr[2] = &sp.basic.action;
-		mptr[3] = &sp.basic.content;
+		mptr[3] = (guint *) &sp.basic.content;
 
 		vbox = gtk_vbox_new(FALSE, 0);
 		gtk_container_set_border_width(GTK_CONTAINER(vbox), 2);
