@@ -20,6 +20,7 @@
 /* 1999-04-25 -	Updated to play by the new selection rules, and also understand that the
 **		path is displayed in a combo, and not a plain GtkEntry. Far less efficient
 **		now, though. Too bad.
+** 2008-09-22 -	Changes for new path entry widget in GTK+ 2.0.
 */
 gint cmd_swap(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 {
@@ -27,11 +28,11 @@ gint cmd_swap(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca)
 
 	tmp = src->dir;
 	src->dir = dst->dir;
-	gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(src->path)->entry), src->dir.path);
 	dst->dir = tmp;
-	gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(dst->path)->entry), dst->dir.path);
 	dp_redisplay_preserve(src);
+	dph_state_restore(src);
 	dp_redisplay_preserve(dst);
+	dph_state_restore(dst);
 
 	return 1;
 }
