@@ -122,8 +122,8 @@ static void link_body(MainInfo *min, DirPane *src, DirRow *row, gpointer user)
 {
 	SleInfo	*sle = user;
 
-	gtk_entry_set_text(GTK_ENTRY(sle->name), DP_ROW_NAME(row));
-	gtk_entry_set_text(GTK_ENTRY(sle->contents), DP_ROW_LINKNAME(row));
+	gtk_entry_set_text(GTK_ENTRY(sle->name), DP_ROW_NAMED(row));
+	gtk_entry_set_text(GTK_ENTRY(sle->contents), DP_ROW_LINKNAMED(row));
 	gtk_entry_select_region(GTK_ENTRY(sle->contents), 0, -1);
 	gtk_widget_grab_focus(sle->contents);
 }
@@ -177,8 +177,9 @@ static void evt_fsel_cancel_clicked(GtkWidget *wid, gpointer user)
 /* 1999-05-30 -	User clicked the "details" button for setting link target from file selector. Pop it up. */
 static void evt_pick_clicked(GtkWidget *wid, gpointer user)
 {
-	gchar	buf[PATH_MAX], *text;
-	SleInfo	*sle = user;
+	const gchar	*text;
+	gchar		buf[PATH_MAX];
+	SleInfo		*sle = user;
 
 	sle->fsel = gtk_file_selection_new(_("Select Link Target"));
 	if(((text = gtk_entry_get_text(GTK_ENTRY(sle->contents))) != NULL) && (*text != '\0'))
@@ -186,8 +187,8 @@ static void evt_pick_clicked(GtkWidget *wid, gpointer user)
 	else
 		g_snprintf(buf, sizeof buf, "%s/", sle->src->dir.path);
 	gtk_file_selection_set_filename(GTK_FILE_SELECTION(sle->fsel), buf);
-	gtk_signal_connect(GTK_OBJECT(GTK_FILE_SELECTION(sle->fsel)->ok_button), "clicked", GTK_SIGNAL_FUNC(evt_fsel_ok_clicked), sle);
-	gtk_signal_connect(GTK_OBJECT(GTK_FILE_SELECTION(sle->fsel)->cancel_button), "clicked", GTK_SIGNAL_FUNC(evt_fsel_cancel_clicked), sle);
+	g_signal_connect(G_OBJECT(GTK_FILE_SELECTION(sle->fsel)->ok_button), "clicked", G_CALLBACK(evt_fsel_ok_clicked), sle);
+	g_signal_connect(G_OBJECT(GTK_FILE_SELECTION(sle->fsel)->cancel_button), "clicked", G_CALLBACK(evt_fsel_cancel_clicked), sle);
 	gtk_widget_show(sle->fsel);
 	gtk_grab_add(sle->fsel);
 }
@@ -214,7 +215,7 @@ gint cmd_symlinkedit(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca
 	sle.contents = gtk_entry_new_with_max_length(PATH_MAX - 1);
 	gtk_table_attach(GTK_TABLE(table), sle.contents, 1, 2, 1, 2,  GTK_EXPAND|GTK_FILL,0,0,0);
 	pick = gui_details_button_new(min->gui->window->window);
-	gtk_signal_connect(GTK_OBJECT(pick), "clicked", GTK_SIGNAL_FUNC(evt_pick_clicked), &sle);
+	g_signal_connect(G_OBJECT(pick), "clicked", G_CALLBACK(evt_pick_clicked), &sle);
 	gtk_table_attach(GTK_TABLE(table), pick, 2, 3, 1, 2,  0,0,0,0);
 	gtk_box_pack_start(GTK_BOX(sle.vbox), table, TRUE, TRUE, 0);
 
@@ -231,9 +232,10 @@ gint cmd_symlinkedit(MainInfo *min, DirPane *src, DirPane *dst, const CmdArg *ca
 		gtk_widget_grab_focus(sle.name);
 		if(dlg_dialog_sync_wait(dlg) == DLG_POSITIVE)
 		{
-			gchar	buf[PATH_MAX], *name, *contents;
-			OvwRes	ores;
-			gint	doit = FALSE;
+			const gchar	*name, *contents;
+			gchar		buf[PATH_MAX];
+			OvwRes		ores;
+			gint		doit = FALSE;
 
 			name = gtk_entry_get_text(GTK_ENTRY(sle.name));
 			if(strchr(name, G_DIR_SEPARATOR) != NULL)
