@@ -30,6 +30,7 @@ typedef struct {			/* Options for the "ViewText" command. */
 	gboolean	use_mmap;			/* Use mmap() for files of non-zero length? */
 	gsize		buf_size;			/* Buffer size, when not using mmap(). */
 	gsize		check_size;			/* The ViewTextOrHex command inspects this many bytes. */
+	gboolean	exit_on_left;			/* Exit text reader on Left Arrow keypress? */
 } OptViewText;
 
 static OptViewText	viewtext_options;
@@ -65,7 +66,7 @@ static gint view_file_text(MainInfo *min, const gchar *full_name)
 {
 	GtkWidget	*txv;
 
-	if((txv = txv_open(min, full_name)) != NULL)
+	if((txv = txv_open(min, NULL)) != NULL)
 	{
 		txv_show(txv);
 		txv_text_load(txv, full_name, viewtext_options.use_mmap, viewtext_options.buf_size);
@@ -81,7 +82,7 @@ static gint view_file_hex(MainInfo *min, const gchar *full_name)
 {
 	GtkWidget	*txv;
 
-	if((txv = txv_open(min, full_name)) != NULL)
+	if((txv = txv_open(min, NULL)) != NULL)
 	{
 		txv_show(txv);
 		txv_text_load_hex(txv, full_name);
@@ -198,12 +199,14 @@ void cfg_viewtext(MainInfo *min)
 		viewtext_options.use_mmap    = TRUE;
 		viewtext_options.buf_size    = (1 << 18);
 		viewtext_options.check_size  = (1 << 9);
+		viewtext_options.exit_on_left = TRUE;
 
 		viewtext_cmc = cmc_config_new("ViewText", &viewtext_options);
 		cmc_field_add_boolean(viewtext_cmc, "modified", NULL, offsetof(OptViewText, modified));
 		cmc_field_add_boolean(viewtext_cmc, "use_mmap", _("Use mmap() to Speed Loading?"), offsetof(OptViewText, use_mmap));
 		cmc_field_add_size(viewtext_cmc, "buf_size", _("Buffer Size"), offsetof(OptViewText, buf_size), 1024, (1 << 20), 1024);
 		cmc_field_add_size(viewtext_cmc, "check_size", _("Hex-Check First"), offsetof(OptViewText, check_size), 32, (1 << 16), 32);
+		cmc_field_add_boolean(viewtext_cmc, "exit_left", _("Exit on Left Arrow Key?"), offsetof(OptViewText, exit_on_left));
 		cmc_config_register(viewtext_cmc);
 	}
 }
