@@ -314,7 +314,7 @@ static gint build_input_menu(CmdDlg *dlg, const gchar *def, CmdInp *inp)
 
 		gtk_object_set_user_data(GTK_OBJECT(item), inp);
 		inp->inp.menu.items = g_list_append(inp->inp.menu.items, (gpointer) itext);
-		gtk_signal_connect(GTK_OBJECT(item), "activate", GTK_SIGNAL_FUNC(evt_menu_activated), GINT_TO_POINTER(index++));
+		g_signal_connect(G_OBJECT(item), "activate", G_CALLBACK(evt_menu_activated), GINT_TO_POINTER(index++));
 		gtk_menu_append(GTK_MENU(menu), item);
 	}
 	gtk_option_menu_set_menu(GTK_OPTION_MENU(obtn), menu);
@@ -443,7 +443,7 @@ static void parse_code_input(MainInfo *min, GString *cstr, gchar *code, CmdDlg *
 		case 's':
 			succ = build_input_string(dlg, def, &dlg->input[dlg->row]);
 			if(dlg->str_count++ == 0)
-				gtk_signal_connect(GTK_OBJECT(dlg->input[dlg->row].inp.string.entry), "realize", GTK_SIGNAL_FUNC(evt_input_string_realize), &dlg->str_focused);
+				g_signal_connect(G_OBJECT(dlg->input[dlg->row].inp.string.entry), "realize", G_CALLBACK(evt_input_string_realize), &dlg->str_focused);
 			break;
 		case 'm':
 			succ = build_input_menu(dlg, def, &dlg->input[dlg->row]);
