@@ -115,7 +115,7 @@ static gboolean key_remove(gpointer key, gpointer value, gpointer user)
 {
 	key_destroy(value);
 	return TRUE;
-} 
+}
 
 /* 1999-03-16 -	Copy a key. A callback for ctrl_copy() below. */
 static void key_copy(gpointer key, gpointer value, gpointer user)
@@ -313,7 +313,7 @@ void ctrl_key_remove_all(CtrlInfo *ctrl)
 }
 
 /* 1999-03-16 -	Return the key part of given key->command mapping. */
-const gchar * ctrl_key_get_keyname(CtrlKey *key)
+const gchar * ctrl_key_get_keyname(const CtrlKey *key)
 {
 	if(key != NULL)
 		return key->keyname;
@@ -321,7 +321,7 @@ const gchar * ctrl_key_get_keyname(CtrlKey *key)
 }
 
 /* 1999-03-16 -	Return the command part of a key-to-command mapping. */
-const gchar * ctrl_key_get_cmdseq(CtrlKey *key)
+const gchar * ctrl_key_get_cmdseq(const CtrlKey *key)
 {
 	if((key != NULL) && (key->cmdseq != NULL))
 		return key->cmdseq->str;
@@ -528,7 +528,7 @@ CtrlMouse * ctrl_mouse_add(CtrlInfo *ctrl, guint button, guint state, const gcha
 
 	if(ctrl != NULL)
 	{
-		CtrlMouse	*cm = mouse_new();
+		cm = mouse_new();
 
 		cm->button = button;
 		cm->state  = state;
@@ -561,7 +561,7 @@ void ctrl_mouse_set_cmdseq(CtrlMouse *mouse, const gchar *cmdseq)
 }
 
 /* 1999-06-13 -	Access the button part of a mouse command mapping. */
-guint ctrl_mouse_get_button(CtrlMouse *mouse)
+guint ctrl_mouse_get_button(const CtrlMouse *mouse)
 {
 	if(mouse != NULL)
 		return mouse->button;
@@ -569,7 +569,7 @@ guint ctrl_mouse_get_button(CtrlMouse *mouse)
 }
 
 /* 1999-06-13 -	Get the state bits for a mouse button command mapping. */
-guint ctrl_mouse_get_state(CtrlMouse *mouse)
+guint ctrl_mouse_get_state(const CtrlMouse *mouse)
 {
 	if(mouse != NULL)
 		return mouse->state;
@@ -577,7 +577,7 @@ guint ctrl_mouse_get_state(CtrlMouse *mouse)
 }
 
 /* 1999-06-13 -	Get the command sequence for a mouse mapping. */
-const gchar * ctrl_mouse_get_cmdseq(CtrlMouse *mouse)
+const gchar * ctrl_mouse_get_cmdseq(const CtrlMouse *mouse)
 {
 	if(mouse != NULL)
 		return mouse->cmdseq->str;
