@@ -28,6 +28,7 @@ struct Dialog {
 };
 
 static struct {
+	GtkWindow	*main_window;
 	GdkWindow	*group_window;
 	GtkWindowPosition window_pos;
 } the_state;
@@ -49,58 +50,34 @@ void dlg_position_set(GtkWindowPosition pos)
 	the_state.window_pos = pos;
 }
 
+/* 2009-03-25 -	Sets the main window, all dialogs are then made transient to this window.
+**		I think this replaces the "group" concept used with GDK windows.
+*/
+void dlg_main_window_set(GtkWindow *win)
+{
+	the_state.main_window = win;
+}
+
 /* ----------------------------------------------------------------------------------------- */
 
-/* 1999-06-19 -	Build a set of action buttons (like "OK", "Cancel" and so on), and pack them into <bo>. Buttons are
-**		defined by writing the desired labels separated by vertical bars (e.g. "OK|Cancel" is very common).
-**		Will connect <func,user> to the "clicked" signal of all buttons. Each button will have its user data
-**		pointer set to the index (counting from 0) of the button.
-**		Returns the index of the last button built (e.g. 1 for the "OK|Cancel" case).
-** 2002-02-21 -	Added accelerator support, with pretty underlines even.
+/* 2004-11-22 -	Add buttons by splitting <buttons> on vertical bar (pipe) character. Far simpler
+ *		than when using GTK+ 1.2, keyboard acceleration now done by GtkDialog.
 */
-static guint build_buttons(const gchar *buttons, GtkWidget *box, GtkSignalFunc func, gpointer user)
+static gint add_buttons(GtkWidget *dlg, const char *buttons)
 {
-	gchar		*ptr, label[DLG_BUTTON_SIZE];
-	gint		index = 0;
-	GtkWidget	*btn;
-	GtkAccelGroup	*ag = NULL;
+	gchar	label[DLG_BUTTON_SIZE], *ptr;
+	gint	response = 0;
 
-	for(index = 0; *buttons; index++)
+	while(*buttons)
 	{
 		for(ptr = label; (ptr - label) < (sizeof label - 1) && *buttons && *buttons != '|';)
 			*ptr++ = *buttons++;
 		*ptr = '\0';
 		if(*buttons == '|')
 			buttons++;
-		if(strchr(label, '_') != NULL)		/* Accelerator in use? */
-		{
-			GtkWidget	*lab;
-			guint		key;
-
-			lab = gtk_label_new("");
-			key = gtk_label_parse_uline(GTK_LABEL(lab), label);
-			btn = gtk_button_new();
-			gtk_container_add(GTK_CONTAINER(btn), lab);
-			if(ag == NULL)
-				ag = gtk_accel_group_new();
-			gtk_widget_add_accelerator(btn, "clicked", ag, key, 0, GTK_ACCEL_VISIBLE);
-		}
-		else
-			btn = gtk_button_new_with_label(label);
-		GTK_WIDGET_SET_FLAGS(btn, GTK_CAN_DEFAULT);
-		gtk_signal_connect(GTK_OBJECT(btn), "clicked", GTK_SIGNAL_FUNC(func), user);
-		gtk_object_set_user_data(GTK_OBJECT(btn), GINT_TO_POINTER(index));
-		gtk_box_pack_start(GTK_BOX(box), btn, TRUE, TRUE, 0);
-		gtk_widget_show_all(btn);
-		if(index == 0)
-		{
-			gtk_widget_grab_default(btn);
-			gtk_widget_grab_focus(btn);
-		}
+		gtk_dialog_add_button(GTK_DIALOG(dlg), label, response++);
 	}
-	if(ag != NULL)
-		gtk_window_add_accel_group(GTK_WINDOW(((Dialog *) user)->dlg), ag);
-	return index - 1;
+	return response - 1;
 }
 
 /* ----------------------------------------------------------------------------------------- */
@@ -111,38 +88,26 @@ static void sync_close(Dialog *dlg, gint button)
 	dlg->button = button;
 	if(!dlg->stay_open)
 		gtk_widget_hide(dlg->dlg);
-	gtk_grab_remove(dlg->dlg);
-	gtk_main_quit();
 }
 
-/* 1999-06-19 -	User clicked the dialog's window close button. Hide it, and return non-button code (-1) to caller. */
-static gboolean evt_sync_delete(GtkWidget *wid, GdkEvent *evt, gpointer user)
+/* 2004-11-22 -	Response-handler for synchronous dialog. */
+static void evt_sync_response(GtkWidget *wid, gint response, void *user)
 {
-	sync_close(user, -1);
-
-	return TRUE;
+	sync_close(user, response >= 0 ? response : -1);
 }
 
+/* 2004-11-22 -	Keyboard handler, so we can cancel through Escape. */
 static gboolean evt_sync_key_pressed(GtkWidget *wid, GdkEventKey *evt, gpointer user)
 {
 	Dialog	*dlg = user;
 
-	switch(evt->keyval)
-	{
-		case GDK_Return:
-			sync_close(dlg, 0);
-			return TRUE;
-		case GDK_Escape:
-			sync_close(dlg, dlg->last_button);
-			return TRUE;
-	}
-	return FALSE;
-}
-
-/* 1999-06-19 -	This gets called when the user clicks a button in a synchronous dialog. */
-static void evt_sync_button_clicked(GtkWidget *wid, gpointer user)
-{
-	sync_close(user, GPOINTER_TO_INT(gtk_object_get_user_data(GTK_OBJECT(wid))));
+	if(evt->keyval == GDK_Return)
+		gtk_dialog_response(GTK_DIALOG(dlg->dlg), 0);
+	if(evt->keyval == GDK_Escape)
+		gtk_dialog_response(GTK_DIALOG(dlg->dlg), dlg->last_button);
+	else
+		return FALSE;
+	return TRUE;
 }
 
 /* 1999-06-19 -	Create a new, synchronous dialog box. Creates and initializes the auxilary data as well as the
@@ -160,8 +125,10 @@ Dialog * dlg_dialog_sync_new(GtkWidget *body, const gchar *title, const gchar *b
 	dlg = g_malloc(sizeof *dlg);
 	dlg->dlg = gtk_dialog_new();
 	gtk_window_set_position(GTK_WINDOW(dlg->dlg), the_state.window_pos);
-	gtk_signal_connect(GTK_OBJECT(dlg->dlg), "delete_event", GTK_SIGNAL_FUNC(evt_sync_delete), dlg);
-	gtk_signal_connect(GTK_OBJECT(dlg->dlg), "key_press_event", GTK_SIGNAL_FUNC(evt_sync_key_pressed), dlg);
+	g_signal_connect(GTK_OBJECT(dlg->dlg), "key_press_event", G_CALLBACK(evt_sync_key_pressed), dlg);
+	g_signal_connect(GTK_OBJECT(dlg->dlg), "response", G_CALLBACK(evt_sync_response), dlg);
+	gtk_dialog_set_default_response(GTK_DIALOG(dlg->dlg), 0);
+	gtk_window_set_transient_for(GTK_WINDOW(dlg->dlg), the_state.main_window);
 	dlg->stay_open = FALSE;
 	if(title != NULL)
 		win_window_set_title(GTK_WIDGET(dlg->dlg), title);
@@ -176,7 +143,7 @@ Dialog * dlg_dialog_sync_new(GtkWidget *body, const gchar *title, const gchar *b
 		gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dlg->dlg)->vbox), vbox, TRUE, TRUE, 0);
 		gtk_widget_show_all(vbox);
 	}
-	dlg->last_button = build_buttons(buttons, GTK_DIALOG(dlg->dlg)->action_area, evt_sync_button_clicked, dlg);
+	dlg->last_button = add_buttons(dlg->dlg, buttons);
 
 	return dlg;
 }
@@ -219,11 +186,8 @@ gint dlg_dialog_sync_wait(Dialog *dlg)
 		int	old_errno = errno;
 
 		gtk_widget_realize(dlg->dlg);
-		gdk_window_set_group(dlg->dlg->window, the_state.group_window);
-		gtk_widget_show(dlg->dlg);
-		gdk_window_raise(dlg->dlg->window);
-		gtk_grab_add(dlg->dlg);
-		gtk_main();
+		gtk_window_set_transient_for(GTK_WINDOW(dlg->dlg), the_state.main_window);
+		gtk_dialog_run(GTK_DIALOG(dlg->dlg));
 		errno = old_errno;
 		return dlg->button;
 	}
@@ -257,35 +221,23 @@ static void async_close(Dialog *dlg, gint button)
 	g_free(dlg);
 }
 
-/* 1999-06-19 -	User closed an asynch. dialog window. */
-static gboolean evt_async_delete(GtkWidget *wid, GdkEvent *evt, gpointer user)
-{
-	async_close(user, -1);
-
-	return TRUE;
-}
-
 /* 1999-06-19 -	User pressed a key in an asynchronous dialog. */
 static gboolean evt_async_key_pressed(GtkWidget *wid, GdkEventKey *evt, gpointer user)
 {
 	Dialog	*dlg = user;
 
-	switch(evt->keyval)
+	if(evt->keyval == GDK_Escape)
 	{
-		case GDK_Return:
-			async_close(dlg, 0);
-			return TRUE;
-		case GDK_Escape:
-			async_close(dlg, dlg->last_button);
-			return TRUE;
+		async_close(dlg, dlg->last_button);
+		return TRUE;
 	}
 	return FALSE;
 }
 
 /* 1999-06-19 -	User clicked one of the action buttons in an asynchronous dialog. */
-static void evt_async_button_clicked(GtkWidget *wid, gpointer user)
+static void evt_async_response(GtkWidget *wid, gint response, gpointer user)
 {
-	async_close(user, GPOINTER_TO_INT(gtk_object_get_user_data(GTK_OBJECT(wid))));
+	async_close(user, response > 0 ? response : -1);
 }
 
 /* 1999-06-19 -	Create, and immediately display, an asynchronous dialog. The supplied callback will be called
@@ -295,6 +247,7 @@ static void evt_async_button_clicked(GtkWidget *wid, gpointer user)
 Dialog * dlg_dialog_async_new(GtkWidget *body, const gchar *title, const gchar *buttons, DlgAsyncFunc func, gpointer user)
 {
 	Dialog		*dlg;
+	gint		old_errno;
 
 	if(buttons == NULL)
 		buttons = _("_OK|_Cancel");
@@ -304,16 +257,18 @@ Dialog * dlg_dialog_async_new(GtkWidget *body, const gchar *title, const gchar *
 	dlg->user = user;
 	dlg->dlg = gtk_dialog_new();
 	gtk_window_set_position(&GTK_DIALOG(dlg->dlg)->window, the_state.window_pos);
-	gtk_signal_connect(GTK_OBJECT(dlg->dlg), "delete_event", GTK_SIGNAL_FUNC(evt_async_delete), dlg);
-	gtk_signal_connect(GTK_OBJECT(dlg->dlg), "key_press_event", GTK_SIGNAL_FUNC(evt_async_key_pressed), dlg);
+	g_signal_connect(G_OBJECT(dlg->dlg), "key_press_event", G_CALLBACK(evt_async_key_pressed), dlg);
+	g_signal_connect(G_OBJECT(dlg->dlg), "response", G_CALLBACK(evt_async_response), dlg);
 	if(title != NULL)
 		win_window_set_title(GTK_WIDGET(&GTK_DIALOG(dlg->dlg)->window), title);
 	gtk_container_set_border_width(GTK_CONTAINER(GTK_DIALOG(dlg->dlg)->vbox), 5);
 	gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dlg->dlg)->vbox), body, TRUE, TRUE, 0);
-	dlg->last_button = build_buttons(buttons, GTK_DIALOG(dlg->dlg)->action_area, evt_async_button_clicked, dlg);
+	dlg->last_button = add_buttons(dlg->dlg, buttons);
 	gtk_widget_realize(dlg->dlg);
-	gdk_window_set_group(dlg->dlg->window, the_state.group_window);
+	old_errno = errno;
+	gtk_window_set_transient_for(GTK_WINDOW(dlg->dlg), the_state.main_window);
 	gtk_widget_show_all(dlg->dlg);
+	errno = old_errno;
 
 	return dlg;
 }
