@@ -18,6 +18,8 @@
 ** 1999-11-13 -	Prettied up handling of vertical position remembering somewhat, exported it separately.
 ** 2002-08-09 -	DHEntries can't be keyed on inode, since that can be fooled by deleting a directory,
 **		and then creating a new (differently named) one. The filesystem can re-use the inode.
+** 2008-01-26 -	Adapted to keep a separate UTF-8 copy of the path names, for GTK+ 2. Ugly, needs to
+**		be way better. Later? Heh.
 */
 
 #include "gentoo.h"
@@ -27,6 +29,7 @@
 #include <unistd.h>
 
 #include "cmdseq.h"
+#include "convutil.h"
 #include "dirpane.h"
 #include "errors.h"
 #include "fileutil.h"
@@ -54,7 +57,8 @@ struct DHSel {
 
 /* Info about a single remembered directory. The 'hist' field of dirpanes stores a list of these. */
 typedef struct {
-	gchar	path[PATH_MAX];		/* The path to this directory. Must be first! */
+	gchar	dpath[2*PATH_MAX];	/* The path to this directory, in UTF-8. Must be first! FIXME: Kind of a gross assumption. */
+	gchar	path[PATH_MAX];		/* The path to this directory. */
 	gchar	realpath[PATH_MAX];	/* Canonical path, used as key since <dev,inode> isn't enough. */
 	DHSel	*sel;			/* The selection last time we were here. */
 	gfloat	vpos;			/* Vertical position. */
@@ -93,8 +97,8 @@ const gchar * dph_dirhistory_get_entry(const DirHistory *dh, guint index)
 {
 	if(dh != NULL)
 	{
-		const DHEntry	*dhe = (const DHEntry *) g_list_nth_data(dh->history, index);
-		if(dhe != NULL)
+		const DHEntry   *dhe = (const DHEntry *) g_list_nth_data(dh->history, index);
+ 		if(dhe != NULL)
 			return dhe->path;
 	}
 	return NULL;
@@ -167,6 +171,7 @@ static DHEntry * dhentry_new(void)
 	DHEntry	*data;
 
 	data = g_malloc(sizeof *data);
+	data->dpath[0] = '\0';
 	data->path[0] = '\0';
 	data->realpath[0] = '\0';
 	data->sel = NULL;
@@ -178,7 +183,14 @@ static DHEntry * dhentry_new(void)
 
 static void dhentry_path_set(DHEntry *dhe, const gchar *path)
 {
+	Conv	conv;
+	gchar	*dpl;
+
 	g_snprintf(dhe->path, sizeof dhe->path, "%s", path);
+	conv_init(&conv);
+	dpl = conv_add_reverse(&conv, path);
+	g_snprintf(dhe->dpath, sizeof dhe->dpath, "%s", dpl);
+	conv_end(&conv);
 }
 
 static void dhentry_realpath_set(DHEntry *dhe, const gchar *realpath)
@@ -190,9 +202,12 @@ static void dhentry_realpath_set(DHEntry *dhe, const gchar *realpath)
 static void dhentry_update(DHEntry *dhe, const DirPane *dp)
 {
 	if(dp->main->cfg.dp_history.select)
-		dhe->sel  = dirsel_set(dhe->sel, dp);
+		dhe->sel = dirsel_set(dhe->sel, dp);
 	else
+	{
+		dph_dirsel_destroy(dhe->sel);
 		dhe->sel = NULL;
+	}
 	dhe->vpos = dph_vpos_get(dp);
 	if(dp->focus_row != -1)
 		dhe->focus_row = dp->focus_row;
@@ -254,8 +269,8 @@ static DHSel * dirsel_set(DHSel *sel, const DirPane *dp)
 
 	if((slist = dp_get_selection_full(dp)) != NULL)
 	{
-		const GSList	*iter;
 		HKey		*key;
+		const GSList	*iter;
 
 		if(sel == NULL)
 			sel = dirsel_new();
@@ -417,10 +432,8 @@ void dph_state_restore(DirPane *dp)
 			}
 		}
 	}
-	/* Update path history widgets. Relies on <path> member being first in DHEntry. */
-	gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(dp->path)->entry), dp->hist->history->data);
-	gtk_editable_changed(GTK_EDITABLE(GTK_COMBO(dp->path)->entry));
-	gtk_combo_set_popdown_strings(GTK_COMBO(dp->path), dp->hist->history);
+	/* Update path history widgets. Relies on <dpath> member being first in DHEntry. */
+	dp_history_set(dp, dp->hist->history);
 }
 
 /* ----------------------------------------------------------------------------------------- */
@@ -465,7 +478,11 @@ void dph_history_save(MainInfo *min, const DirPane *dp, gsize num)
 		xml_put_uinteger(out, "index", i);
 		xml_put_node_open(out, "History");
 		for(iter = dp[i].hist->history; iter != NULL; iter = g_list_next(iter))
+		{
+			if(*(gchar *) iter->data == '\0')
+				continue;
 			xml_put_text(out, "dir", iter->data);
+		}
 		xml_put_node_close(out, "History");
 		xml_put_node_close(out, "Pane");
 	}
@@ -485,10 +502,20 @@ static void load_dir(const XmlNode *node, gpointer user)
 
 	if(!xml_get_text(node, "dir", &text))
 		return;
+	if(text && *text == '\0')
+		return;
 	ent = dhentry_new();
 	stu_strncpy(ent->path, text, sizeof ent->path);
 	if(realpath(ent->path, ent->realpath) != NULL)
+	{
+		Conv		conv;
+		const gchar	*display;
+
+		display = conv_begin_reverse(&conv, ent->path);
+		g_strlcpy(ent->dpath, display, sizeof ent->dpath);
 		dp->hist->history = g_list_append(dp->hist->history, ent);
+		conv_end(&conv);
+	}
 	else
 		dhentry_destroy(ent);
 }
