@@ -14,7 +14,7 @@ typedef struct DirHistory	DirHistory;
 
 extern DirHistory *	dph_dirhistory_new(void);
 
-const gchar *		dph_dirhistory_get_entry(const DirHistory *dh, guint index);
+extern const gchar *	dph_dirhistory_get_entry(const DirHistory *dh, guint index);
 
 extern DHSel *		dph_dirsel_new(DirPane *dp);
 extern void		dph_dirsel_apply(DirPane *dp, const DHSel *sel);
