@@ -310,13 +310,12 @@ static void evt_path_new(GtkWidget *wid, gpointer user)
 	csq_execute_format(dp->main, "DirEnter 'dir=%s'", stu_escape(dir));
 	conv_end(&conv);
 	dp_path_unfocus(dp);
-	g_free(dir);
 }
 
 static void evt_path_changed(GtkWidget *wid, gpointer user)
 {
-	gint		index;
-	const gchar	*now;
+	gint	index;
+	gchar	*now;
 
 	now = gtk_combo_box_get_active_text(GTK_COMBO_BOX(wid));
 	index = gtk_combo_box_get_active(GTK_COMBO_BOX(wid));
