@@ -596,15 +596,15 @@ int fut_path_component(const gchar *paths, gchar *component)
 **		braces {around} any combination of characters to force a look-up on that.
 */
 static void eval_env(gchar *component)
-{ 
+{
 	GString	*temp = NULL;
-	gchar	*ptr, vname[256], *vptr, *vval;
+	gchar	*ptr, vname[256], *vptr;
 
 	for(ptr = component; *ptr != '\0'; ptr++)
 	{
 		if(*ptr == '$')		/* Environment variable? */
 		{
-			const gchar	*start = ptr;
+			const gchar	*start = ptr, *vval;
 
 			ptr++;
 			if(*ptr == '{')		/* Braced name? */
@@ -852,7 +852,7 @@ off_t fut_copy(gint in, gint out, gsize chunk_size)
 			wrote = write(out, wbuf, to_write);
 			if(wrote < 0)
 			{
-				fprintf(stderr, "gentoo: fut_copy() failed to write %d-byte block, errno=%d--aborting copy\n", got, errno);
+				fprintf(stderr, "gentoo: fut_copy() failed to write %" G_GSSIZE_FORMAT "-byte block, errno=%d--aborting copy\n", got, errno);
 				goto fail;
 			}
 		}
