@@ -37,8 +37,6 @@
 #include "cmdseq_config.h"
 #include "menus.h"
 
-#include "odlabel.h"
-
 #include "cfg_module.h"
 #include "cfg_windows.h"
 
@@ -71,9 +69,7 @@ static gint quit_handler(gpointer user)
 /* 2000-03-18 -	User clicked close button on window. Just react as if the Quit command was run. */
 static gboolean evt_main_delete(GtkWidget *wid, GdkEventAny *evt, gpointer user)
 {
-	MainInfo	*min = user;
-
-	csq_execute(min, "Quit");
+	csq_execute(user, "Quit");
 
 	return TRUE;
 }
@@ -82,8 +78,7 @@ static gboolean evt_main_delete(GtkWidget *wid, GdkEventAny *evt, gpointer user)
 static void init_pane(DirPane *dp, gint index)
 {
 	dp->index = index;
-	dp->complete.list = NULL;
-	dp->complete.iter = NULL;
+	dp->complete.prefix[0] = '\0';
 	dp->dir.row = NULL;
 	dp->dir.row_alloc = 0;
 	dp->dir.num_rows  = 0;
@@ -97,14 +92,17 @@ static void init_pane(DirPane *dp, gint index)
 	dp->dir.path[0] = '\0';
 }
 
-static void evt_pane_sizealloc(GtkWidget *wid, GtkAllocation *alloc, gpointer user)
+static void evt_paned_notify_position(GObject *obj, GParamSpec *spec, gpointer user)
 {
 	MainInfo	*min = user;
 	gint		pos, ww;
 	gdouble		old;
 
-	pos = alloc->width;
-	gdk_window_get_size(((MainInfo *) user)->gui->window->window, &ww, NULL);
+	pos = gtk_paned_get_position(GTK_PANED(obj));
+	gdk_window_get_size(min->gui->window->window, &ww, NULL);
+	/* If window is not configured yet, the size returned here is dubious. */
+	if(!min->gui->win_configured)
+		return;
 	old = min->cfg.dp_paning.value;
 	switch(min->cfg.dp_paning.mode)
 	{
@@ -120,22 +118,6 @@ static void evt_pane_sizealloc(GtkWidget *wid, GtkAllocation *alloc, gpointer us
 			min->cfg.dp_paning.value = ww - pos;
 			break;
 	}
-	gtk_signal_handler_block(GTK_OBJECT(min->gui->pane[0].vbox), min->gui->sig_left_sizealloc);
-	if(min->cfg.dp_paning.value != old)
-		cfg_modified_set(min);
-}
-
-/* 2001-08-04 -	Track release of GtkPaned handle, and react according to current mode. */
-static gboolean evt_paned_buttonrelease(GtkWidget *wid, GdkEventButton *evt, gpointer user)
-{
-	if(evt->window == GTK_PANED(wid)->handle)
-	{
-		MainInfo	*min = user;
-
-		gtk_signal_handler_unblock(GTK_OBJECT(min->gui->pane[0].vbox), min->gui->sig_left_sizealloc);
-		return TRUE;
-	}
-	return FALSE;
 }
 
 /* 1998-05-17 -	Build a couple of dir-panes.
@@ -150,15 +132,13 @@ static GtkWidget * build_dirpanes(MainInfo *min)
 	gui = min->gui;
 
 	gui->panes = min->cfg.dp_paning.orientation == DPORIENT_HORIZ ? gtk_hpaned_new() : gtk_vpaned_new();
-	gtk_signal_connect(GTK_OBJECT(gui->panes), "button_release_event", GTK_SIGNAL_FUNC(evt_paned_buttonrelease), min);
 	init_pane(&gui->pane[0], 0);
 	pane = dp_build(min, &min->cfg.dp_format[0], &gui->pane[0]);
 	gtk_paned_add1(GTK_PANED(gui->panes), pane);
 	init_pane(&gui->pane[1], 1);
 	pane = dp_build(min, &min->cfg.dp_format[1], &gui->pane[1]);
 	gtk_paned_add2(GTK_PANED(gui->panes), pane);
-	gtk_paned_set_handle_size(GTK_PANED(gui->panes), 10);
-	gtk_paned_set_gutter_size(GTK_PANED(gui->panes), 10);
+	gui->sig_pane_notify = g_signal_connect(G_OBJECT(gui->panes), "notify::position", G_CALLBACK(evt_paned_notify_position), min);
 	gtk_widget_show(gui->panes);
 
 	return gui->panes;
@@ -173,15 +153,11 @@ static GtkWidget * build_dirpanes(MainInfo *min)
 */
 static GtkWidget * build_top(GtkWidget **label)
 {
-	GtkWidget	*top, *lab, *hbox;
+	GtkWidget	*top, *lab;
 
 	top = gtk_event_box_new();
-	hbox = gtk_hbox_new(FALSE, 0);
-	lab = od_label_new("");
-	gtk_widget_set_name(lab, "mainStatus");
-	GTK_WIDGET_SET_FLAGS(GTK_WIDGET(lab), GTK_CAN_FOCUS);
-	gtk_box_pack_start(GTK_BOX(hbox), lab, TRUE, TRUE, 0);
-	gtk_container_add(GTK_CONTAINER(top), hbox);
+	lab = gtk_label_new("");
+	gtk_container_add(GTK_CONTAINER(top), lab);
 	gtk_widget_show_all(top);
 	if(label != NULL)
 		*label = lab;
@@ -215,13 +191,10 @@ void rebuild_middle(MainInfo *min)
 	gtk_box_pack_start(GTK_BOX(min->gui->vbox), min->gui->panes, TRUE, TRUE, 0);
 	gtk_box_reorder_child(GTK_BOX(min->gui->vbox), min->gui->panes, 1);
 	if((left = dp_build(min, &min->cfg.dp_format[0], &min->gui->pane[0])) != NULL)
-	{
-		min->gui->sig_left_sizealloc = gtk_signal_connect(GTK_OBJECT(left), "size_allocate", GTK_SIGNAL_FUNC(evt_pane_sizealloc), min);
-		gtk_signal_handler_block(GTK_OBJECT(left), min->gui->sig_left_sizealloc);
 		gtk_paned_add1(GTK_PANED(min->gui->panes), left);
-	}	
 	if((right = dp_build(min, &min->cfg.dp_format[1], &min->gui->pane[1])) != NULL)
 		gtk_paned_add2(GTK_PANED(min->gui->panes), right);
+	min->gui->sig_pane_notify = g_signal_connect(G_OBJECT(min->gui->panes), "notify::position", G_CALLBACK(evt_paned_notify_position), min);
 	gtk_widget_show(min->gui->panes);
 }
 
@@ -267,8 +240,8 @@ static void window_set_icon(GtkWidget *win)
 	}
 }
 
-/* 2001-08-04 -	Update GtkHPaned handle position to maintain the configured split. */
-static void evt_main_sizealloc(GtkWidget *wid, GtkAllocation *alloc, gpointer user)
+/* 2008-04-20 -	Replaced old size_allocation-tracking code with new, using configure events instead. */
+static gboolean evt_main_configure(GtkWidget *wid, GdkEventConfigure *req, gpointer user)
 {
 	MainInfo	*min = user;
 	gint		pos = -1;
@@ -276,19 +249,28 @@ static void evt_main_sizealloc(GtkWidget *wid, GtkAllocation *alloc, gpointer us
 	switch(min->cfg.dp_paning.mode)
 	{
 		case DPSPLIT_FREE:
-			return;
+			return FALSE;
 		case DPSPLIT_RATIO:
-			pos = alloc->width * min->cfg.dp_paning.value;
+			pos = req->width * min->cfg.dp_paning.value;
 			break;
 		case DPSPLIT_ABS_LEFT:
 			pos = min->cfg.dp_paning.value;
 			break;
 		case DPSPLIT_ABS_RIGHT:
-			pos = alloc->width - min->cfg.dp_paning.value;
+			pos = req->width - min->cfg.dp_paning.value;
 			break;
 	}
 	if(pos > 0)
+	{
+		g_signal_handler_block(G_OBJECT(min->gui->window), min->gui->sig_main_configure);
+		g_signal_handler_block(G_OBJECT(min->gui->panes), min->gui->sig_pane_notify);
 		gtk_paned_set_position(GTK_PANED(min->gui->panes), pos);
+		g_signal_handler_unblock(G_OBJECT(min->gui->panes), min->gui->sig_pane_notify);
+		g_signal_handler_unblock(G_OBJECT(min->gui->window), min->gui->sig_main_configure);
+	}
+	min->gui->win_configured = TRUE;
+
+	return FALSE;	/* Keep propagating. */
 }
 
 static GtkWidget * build_gui(MainInfo *min)
@@ -299,13 +281,14 @@ static GtkWidget * build_gui(MainInfo *min)
 	min->gui->window = NULL;
 	min->gui->window = win_window_open(min->cfg.wininfo, WIN_MAIN);
 	gtk_object_set_user_data(GTK_OBJECT(min->gui->window), min);
-	gtk_signal_connect(GTK_OBJECT(min->gui->window), "size_allocate", GTK_SIGNAL_FUNC(evt_main_sizealloc), min);
+	min->gui->sig_main_configure = g_signal_connect(G_OBJECT(min->gui->window), "configure_event", G_CALLBACK(evt_main_configure), min);
+	min->gui->sig_main_delete = g_signal_connect(G_OBJECT(min->gui->window), "delete_event", G_CALLBACK(evt_main_delete), min);
+	min->gui->win_configured = FALSE;
 	min->gui->pane[0].main = min->gui->pane[1].main = min;
 	min->gui->pane[0].list = min->gui->pane[1].list = NULL;
 	min->gui->vbox = gtk_vbox_new(FALSE, 0);
 	min->gui->main_tt = gtk_tooltips_new();
 	min->gui->kbd_ctx = kbd_context_new(min);
-	min->gui->sig_left_sizealloc = 0U;
 
 	top = build_top(&min->gui->top);
 	if((panes = build_dirpanes(min)) != NULL)
@@ -314,8 +297,7 @@ static GtkWidget * build_gui(MainInfo *min)
 		gtk_box_pack_start(GTK_BOX(min->gui->vbox), top,    FALSE, FALSE, 0);
 		gtk_box_pack_start(GTK_BOX(min->gui->vbox), panes,  TRUE,  TRUE,  0);
 		gtk_box_pack_start(GTK_BOX(min->gui->vbox), bottom, FALSE, FALSE, 0);
-		gtk_widget_show(bottom);
-		gtk_widget_show(min->gui->vbox);
+		gtk_widget_show_all(min->gui->vbox);
 		min->gui->middle = panes;
 		min->gui->bottom = bottom;
 		min->gui->cur_pane = &min->gui->pane[0];
@@ -458,12 +440,8 @@ static gint evt_idle_run(gpointer user)
 
 int main(int argc, char *argv[])
 {
-	enum { OPT_VERSION = 1 << 0, OPT_LOCALEINFO = 1 << 1, OPT_ROOTOK = 1 << 2,
-		OPT_NORC = 1 << 3, OPT_NOGTKRC = 1 << 4, OPT_NOFAM = 1 << 5 };
+	enum { OPT_VERSION = 1 << 0, OPT_ROOTOK = 1 << 1, OPT_NORC = 1 << 2, OPT_NOGTKRC = 1 << 3, OPT_NOFAM = 1 << 4 };
 	OptDesc	od[] = { { '\0', "version",  OPT_ARG_NONE, OPT_VERSION,	N_("Report the version to standard output, and exit.") },
-#if defined ENABLE_NLS
-			 { '\0', "locale-info", OPT_ARG_NONE, OPT_LOCALEINFO, N_("Report internal locale details, and exit.") },
-#endif
 			 { '\0', "root-ok",  OPT_ARG_NONE, OPT_ROOTOK,	N_("Allows gentoo to be run by the root user. Could be dangerous.") },
 			 { '\0', "no-rc",    OPT_ARG_NONE, OPT_NORC,	N_("Do not load the ~/.gentoorc configuration file; instead, use default values.") },
 			 { '\0', "no-gtkrc", OPT_ARG_NONE, OPT_NOGTKRC,	N_("Do not load the ~/.gentoogtkrc GTK+ configuration file; instead, use system defaults.") },
@@ -482,24 +460,21 @@ int main(int argc, char *argv[])
 	/* Make options available to idle callback that runs commands from invocation. A bit ugly. */
 	min.opt     = od;
 	min.opt_num = sizeof od / sizeof *od;
-	
+
 #if defined ENABLE_NLS
 	setlocale(LC_ALL, "");
-	if(bindtextdomain(PACKAGE, LOCALEDIR) == NULL)
-	{
-		fprintf(stderr, _("%s: Couldn't set text domain to \"%s\"\n"), argv[0], LOCALEDIR);
-		return EXIT_FAILURE;
-	}
+	bindtextdomain(PACKAGE, LOCALEDIR);
 	textdomain(PACKAGE);
 	for(opt_flags = 0; opt_flags < sizeof od / sizeof *od; opt_flags++)
 		od[opt_flags].help = _(od[opt_flags].help);
 	gtk_set_locale();
 #endif
+	/* Must be run early, before anyone changes the directory. */
+	fut_initialize();
 
-	/* First, let GTK+ eat any options it feels an urge for. */
+	/* Must be run before application-level options parsing. */
 	gtk_init(&argc, &argv);
 
-	/* Then, do our own options parsing. */
 	opt_flags = opt_parse(&argc, argv, od, sizeof od / sizeof *od);
 	if(argc < 1)
 		return argc < -1 ? EXIT_FAILURE : EXIT_SUCCESS;
@@ -508,26 +483,14 @@ int main(int argc, char *argv[])
 		puts(VERSION);
 		return EXIT_SUCCESS;
 	}
-#if defined ENABLE_NLS
-	if(opt_flags & OPT_LOCALEINFO)
-	{
-		printf("PACKAGE=\"%s\"\n", PACKAGE);
-		printf("LOCALEDIR=\"%s\"\n", LOCALEDIR);
-		return EXIT_SUCCESS;
-	}
-#endif
 	if(geteuid() == 0 && !(opt_flags & OPT_ROOTOK))
 	{
 		fprintf(stderr, _("%s: To run as root, envoke with the '--root-ok' option\n"), argv[0]);
 		return EXIT_FAILURE;
 	}
 
-	/* Must be run early, before anyone changes the directory. */
-	fut_initialize();
-
 	gtk_quit_add(1, quit_handler, &min);
 
-	dp_initialize();
 	dpf_initialize();
 	sze_initialize();
 	mnu_initialize();
@@ -548,8 +511,6 @@ int main(int argc, char *argv[])
 	min.cfg.dir_filter = dir_filter;
 	chd_initialize(&min);
 	min.que = que_initialize();
-	
-	ctrl_general_set_cmdseq(min.cfg.ctrlinfo, CTRL_GENERAL_PATH_RMB, "About");
 
 	min.ico = ico_initialize(&min);
 
@@ -570,14 +531,15 @@ int main(int argc, char *argv[])
 	{
 		gchar	welcome[128];
 
-		dlg_group_set(min.gui->window->window);
+		dp_initialize(min.gui->pane);
+
+		dlg_main_window_set(GTK_WINDOW(min.gui->window));
 		dlg_position_set(min.cfg.dialogs.pos);
-		min.gui->win_del_evt = gtk_signal_connect(GTK_OBJECT(min.gui->window), "delete_event", GTK_SIGNAL_FUNC(evt_main_delete), &min);
 #if 0
-		gtk_signal_connect(GTK_OBJECT(min.gui->window), "key_press_event", GTK_SIGNAL_FUNC(evt_key_press), &min);
+		g_signal_connect(G_OBJECT(min.gui->window), "key_press_event", G_CALLBACK(evt_key_press), &min);
 #endif
 		min.cfg.flags = 0;
-		init_cmd_options(&min.cfg);		
+		init_cmd_options(&min.cfg);
 
 		gtk_container_add(GTK_CONTAINER(min.gui->window), box);
 
@@ -590,16 +552,15 @@ int main(int argc, char *argv[])
 		window_set_icon(min.gui->window);
 		win_window_show(min.gui->window);
 
-		min.gui->sig_left_sizealloc = gtk_signal_connect(GTK_OBJECT(min.gui->pane[0].vbox), "size_allocate",
-								GTK_SIGNAL_FUNC(evt_pane_sizealloc), &min);
-		gtk_signal_handler_block(GTK_OBJECT(min.gui->pane[0].vbox), min.gui->sig_left_sizealloc);
-
 		enter_initial_dirs(&min, opt_arg_get("left", od, sizeof od / sizeof *od), opt_arg_get("right", od, sizeof od / sizeof *od));
-
-		g_snprintf(welcome, sizeof welcome, _("gentoo v%s by Emil Brink <emil@obsession.se>"), VERSION);
-		gtk_label_set_text(GTK_LABEL(min.gui->top), welcome);
+		if(errno == 0)
+		{
+			g_snprintf(welcome, sizeof welcome, _("gentoo v%s by Emil Brink <emil@obsession.se>"), VERSION);
+			gtk_label_set_text(GTK_LABEL(min.gui->top), welcome);
+		}
 
 		gtk_idle_add(evt_idle_run, &min);
+		err_clear(&min);
 		gtk_main();
 	}
 	fam_shutdown(&min);
