@@ -459,7 +459,6 @@ typedef struct {			/* A filename, in both on-disk and display formats. */
 typedef struct {			/* Representation of a single line in a directory (a file, typically). */
 	DRName		dr_names;		/* Actual filename, in two representations. */
 	DRName		dr_linknames;		/* Link name, again in two representations. */
-	const gchar	*dr_name, *dr_linkname;	/* Backward compatibility. */
 	struct stat	dr_lstat;		/* From a call to lstat(). */
 	struct stat	*dr_stat;		/* If link, this holds link target stats. Else, it points at dr_lstat. */
 	guint32		dr_flags;		/* Misc. flags. */
@@ -532,7 +531,7 @@ struct GuiInfo {
 	GtkTooltips	*main_tt;		/* Tooltips for main window. Used by dirpane widgets. */
 	KbdContext	*kbd_ctx;		/* Keyboard context, for shortcuts. */
 	GtkWidget	*vbox;			/* Vbox that contains entire GUI. */
-	GtkWidget	*top;			/* A label showing status (selections, free spac, etc). */
+	GtkWidget	*top;			/* A label showing status (selections, free space, etc). */
 	GtkWidget	*panes;			/* GtkPaned widget holding DirPanes. */
 	guint		sig_pane_notify;	/* Signal handler ID for notify::position. */
 	GtkWidget	*middle;		/* A box holding entire middle part. */
