@@ -12,8 +12,6 @@
 
 /* ----------------------------------------------------------------------------------------- */
 
-#include "graphics/icon_details.xpm"
-
 typedef struct {
 	Dialog		*dlg;
 	GtkWidget	*vbox;
@@ -23,6 +21,17 @@ typedef struct {
 	gboolean	terminate;
 } PBar;
 
+typedef struct
+{
+	GObject	*object;
+	gulong	handler;
+} SigHandler;
+
+struct GuiHandlerGroup
+{
+	GList	*handlers;
+};
+
 /* ----------------------------------------------------------------------------------------- */
 
 /* 1998-07-12 -	Moved this out of the dirpane config module and into this brand new GUI
@@ -41,18 +50,18 @@ GtkWidget * gui_arrow_button_new(GtkArrowType at)
 
 /* 1999-04-26 -	Create a button with a "details" icon on it. This is typically a magnifying
 **		class. This button is a graphical replacement for a button labeled "...".
+** 2009-04-23 -	Happy ten year anniversary, gui_details_button_new()! W00t! Rewritten to use
+**		GTK+ 2.0 stock image, GTK_STOCK_FIND is what we use. It used to be a magnifying
+**		glass, but in current GTK+ it's a pair of binoculars. Oh well.
 */
 GtkWidget * gui_details_button_new(GdkWindow *win)
 {
-	GtkWidget	*btn, *pmap;
-	GdkPixmap	*pix;
-	GdkBitmap	*msk;
+	GtkWidget	*btn, *img;
 
 	btn = gtk_button_new();
-	pix = gdk_pixmap_create_from_xpm_d(win, &msk, NULL, icon_details_xpm);
-	pmap = gtk_pixmap_new(pix, msk);
-	gtk_container_add(GTK_CONTAINER(btn), pmap);
-	gtk_widget_show(pmap);
+	/* This is a bit of a hack; even the MENU size is not quite small enough. */
+	img = gtk_image_new_from_stock(GTK_STOCK_FIND, GTK_ICON_SIZE_MENU);
+	gtk_button_set_image(GTK_BUTTON(btn), img);
 	return btn;
 }
 
@@ -174,6 +183,64 @@ GtkWidget * gui_build_menu(const gchar *text[], GtkSignalFunc func, gpointer use
 
 /* ----------------------------------------------------------------------------------------- */
 
+GuiHandlerGroup * gui_handler_group_new(void)
+{
+	GuiHandlerGroup	*g;
+
+	g = g_slice_new(GuiHandlerGroup);
+	if(g != NULL)
+	{
+		g->handlers = NULL;
+	}
+	return g;
+}
+
+gulong gui_handler_group_connect(GuiHandlerGroup *g, GObject *obj, const gchar *signal, GCallback cb, gpointer user)
+{
+	SigHandler	*sh;
+
+	if(g == NULL || obj == NULL || signal == NULL || cb == NULL)
+		return 0ul;
+
+	if((sh = g_slice_new(SigHandler)) == NULL)
+		return 0ul;
+	sh->object = obj;
+	sh->handler = g_signal_connect(obj, signal, cb, user);
+	/* Prepend, for O(1) performance; order doesn't really matter. */
+	g->handlers = g_list_prepend(g->handlers, sh);
+
+	/* Return handler ID, if user code wants to play with it. */
+	return sh->handler;
+}
+
+void gui_handler_group_block(const GuiHandlerGroup *g)
+{
+	const GList	*iter;
+
+	if(g == NULL)
+		return;
+	for(iter = g->handlers; iter != NULL; iter = g_list_next(iter))
+	{
+		const SigHandler *sh = iter->data;
+		g_signal_handler_block(sh->object, sh->handler);
+	}
+}
+
+void gui_handler_group_unblock(const GuiHandlerGroup *g)
+{
+	const GList	*iter;
+
+	if(g == NULL)
+		return;
+	for(iter = g->handlers; iter != NULL; iter = g_list_next(iter))
+	{
+		const SigHandler *sh = iter->data;
+		g_signal_handler_unblock(sh->object, sh->handler);
+	}
+}
+
+/* ----------------------------------------------------------------------------------------- */
+
 /* 2008-07-04 -	Flush pending GTK+ events. This is handy as a separate function, even though
 **		it's only two lines of actual code. It seems that on some systems (Ubuntu),
 **		GTK+ smashes errno when running the event flush, and this encapsulation
