@@ -13,4 +13,12 @@ extern void		gui_progress_end(gpointer anchor);
 
 extern GtkWidget *	gui_build_menu(const gchar *text[], GtkSignalFunc func, gpointer data);
 
+typedef struct GuiHandlerGroup	GuiHandlerGroup;
+
+extern GuiHandlerGroup*	gui_handler_group_new(void);
+extern gulong		gui_handler_group_connect(GuiHandlerGroup *g, GObject *obj, const gchar *signal, GCallback cb, gpointer user);
+extern void		gui_handler_group_block(const GuiHandlerGroup *g);
+extern void		gui_handler_group_unblock(const GuiHandlerGroup *g);
+
 extern void		gui_events_flush(void);
+
