@@ -268,10 +268,16 @@ gint kbd_context_attach(KbdContext *ctx, GtkWindow *win)
 */
 void kbd_context_detach(KbdContext *ctx, GtkWindow *win)
 {
+	gulong	handler;
+
 	if((ctx == NULL) || (win == NULL))
 		return;
 
-	gtk_signal_disconnect_by_func(GTK_OBJECT(win), GTK_SIGNAL_FUNC(evt_key_press), ctx);
+	if((handler = g_signal_handler_find(G_OBJECT(win), G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA,
+			0u, 0, NULL, G_CALLBACK(evt_key_press), ctx)) != 0)
+	{
+		g_signal_handler_disconnect(G_OBJECT(win), handler);
+	}
 }
 
 /* ----------------------------------------------------------------------------------------- */
