@@ -284,6 +284,8 @@ PgsRes pgs_progress_item_update(MainInfo *min, off_t pos)
 
 	if(pgs_info.dlg != NULL)
 	{
+		gint	old_errno = errno;
+
 		g_get_current_time(&time_now);
 		if(pgs_info.delayed)
 		{
@@ -297,8 +299,6 @@ PgsRes pgs_progress_item_update(MainInfo *min, off_t pos)
 		}
 		if(!pgs_info.delayed)
 		{
-			gint	old_errno;
-
 			if(pgs_info.eta != NULL)
 			{
 				gfloat	secs = msu_diff_timeval(&pgs_info.time_begin, &time_now);
@@ -318,17 +318,16 @@ PgsRes pgs_progress_item_update(MainInfo *min, off_t pos)
 					gtk_label_set_text(GTK_LABEL(pgs_info.eta), buf);
 				}
 			}
-			old_errno = errno;
 			gtk_widget_realize(pgs_info.dlg);
 			gdk_window_set_group(pgs_info.dlg->window, pgs_info.min->gui->window->window);
 			gtk_widget_show_all(pgs_info.dlg);
-			errno = old_errno;
 		}
 		if(pgs_info.show_byte && pgs_info.byte_tot)
 			gtk_progress_bar_update(GTK_PROGRESS_BAR(pgs_info.byte_pgs), (gfloat) (pgs_info.byte_pos + pos) / pgs_info.byte_tot);
 		if(pgs_info.show_item && pgs_info.item_size)
 			gtk_progress_bar_update(GTK_PROGRESS_BAR(pgs_info.item_pgs), (gfloat) pos / pgs_info.item_size);
 		gui_events_flush();
+		errno = old_errno;
 		if(pgs_info.cancel)
 			return PGS_CANCEL;
 	}
