@@ -69,8 +69,8 @@ void sze_initialize(void)
 	g_snprintf(size_format.none, sizeof size_format.none, _("%%%s"), G_GUINT64_FORMAT);
 	g_snprintf(size_format.bytes, sizeof size_format.bytes, _("%%%s bytes"), G_GUINT64_FORMAT);
 	g_snprintf(size_format.kb, sizeof size_format.kb, _("%%%s KB"), G_GUINT64_FORMAT);
-	g_snprintf(size_format.kb, sizeof size_format.mb, _("%%%s MB"), G_GUINT64_FORMAT);
-	g_snprintf(size_format.kb, sizeof size_format.gb, _("%%%s GB"), G_GUINT64_FORMAT);
+	g_snprintf(size_format.mb, sizeof size_format.mb, _("%%%s MB"), G_GUINT64_FORMAT);
+	g_snprintf(size_format.gb, sizeof size_format.gb, _("%%%s GB"), G_GUINT64_FORMAT);
 }
 
 /* ----------------------------------------------------------------------------------------- */
