@@ -1384,12 +1384,24 @@ gboolean stl_style_property_is_unique(Style *stl, const gchar *property)
 	return FALSE;
 }
 
-/* 2004-02-24 -	Traverse and propagate property renaming downwards in tree. Recursive. */
+/* 2009-04-22 -	Major rewrite. This doesn't actually do a rename; it does a delete of all non-overriden
+**		properties of the correct name. These, by definition, have the same value as the property
+**		in the parent, so no user-owned information is lost.
+*/
 static void traverse_property_rename(GNode *node, gpointer user)
 {
 	struct property_rename_data	*data = user;
+	Style				*here = node->data;
+	const StlProp			*pr;
 
-	stl_style_property_rename(node->data, data->name_old, data->name_new);
+	if((pr = g_hash_table_lookup(here->properties, data->name_old)) != NULL)
+	{
+		/* If this child overrides the property, abort. */
+		if(pr->override)
+			return;
+		stl_style_property_remove(here, data->name_old);
+		g_node_children_foreach(node, G_TRAVERSE_ALL, traverse_property_rename, data);
+	}
 }
 
 /* 1999-05-25 -	Rename <property> to <new_name>. If there is already a property with that name
@@ -1399,35 +1411,38 @@ static void traverse_property_rename(GNode *node, gpointer user)
 */
 gboolean stl_style_property_rename(Style *stl, const gchar *property, const gchar *new_name)
 {
-	if((stl != NULL) && (property != NULL) && (new_name != NULL))
+	StlProp	*pr;
+	GNode	*me;
+
+	if(stl == NULL || property == NULL || new_name == NULL)
+		return FALSE;
+	if(g_hash_table_lookup(stl->properties, new_name) != NULL)
+		return FALSE;
+	if((pr = g_hash_table_lookup(stl->properties, property)) == NULL)
+		return FALSE;
+	if(!pr->override)
 	{
-		if(g_hash_table_lookup(stl->properties, new_name) == NULL)
-		{
-			StlProp	*pr;
-
-			if((pr = g_hash_table_lookup(stl->properties, property)) != NULL)
-			{
-				GNode	*me;
-
-				/* Remove from hash table, rename, and re-insert. */
-				g_hash_table_remove(stl->properties, pr->name);
-				stu_strncpy(pr->name, new_name, sizeof pr->name);
-				g_hash_table_insert(stl->properties, pr->name, pr);
-				/* Name changed. Now traverse children, and do the same there. Yucky. */
-				if((me = g_node_find(stl->styleinfo->styles, G_PRE_ORDER, G_TRAVERSE_ALL, stl)) != NULL)
-				{
-					struct property_rename_data	data;
-
-					data.style = stl;
-					g_snprintf(data.name_old, sizeof data.name_old, "%s", property);
-					g_snprintf(data.name_new, sizeof data.name_new, "%s", new_name);
-					g_node_children_foreach(me, G_TRAVERSE_ALL, traverse_property_rename, &data);
-				}
-				return TRUE;
-			}
-		}
+		fprintf(stderr, "**Styles: can't rename non-overriden property '%s'\n", property);
+		return FALSE;
 	}
-	return FALSE;
+	/* Remove from hash table, rename, and re-insert. */
+	g_hash_table_remove(stl->properties, pr->name);
+	stu_strncpy(pr->name, new_name, sizeof pr->name);
+	g_hash_table_insert(stl->properties, pr->name, pr);
+	/* Name changed. Now traverse children, and remove non-overridden instances. */
+	if((me = g_node_find(stl->styleinfo->styles, G_PRE_ORDER, G_TRAVERSE_ALL, stl)) != NULL)
+	{
+		struct property_rename_data	data;
+
+		data.style = stl;
+		g_snprintf(data.name_old, sizeof data.name_old, "%s", property);
+		g_snprintf(data.name_new, sizeof data.name_new, "%s", new_name);
+		g_node_children_foreach(me, G_TRAVERSE_ALL, traverse_property_rename, &data);
+	}
+	/* Finally re-inherit stuff, if our override was of a parent's property we will now get it "back". */
+	styleinfo_update(stl->styleinfo);
+
+	return TRUE;
 }
 
 /* 1999-05-19 -	Remove (and destroy) a property from a style. */
