@@ -24,6 +24,7 @@
 
 #include <gdk/gdkkeysyms.h>
 
+#include "convutil.h"
 #include "errors.h"
 #include "fileutil.h"
 #include "dirpane.h"
@@ -194,7 +195,7 @@ void txv_text_append_with_color(GtkWidget *wid, const gchar *text, gsize length,
 	g_snprintf(tname, sizeof tname, "txv-%04x%04x%04x", color->red, color->green, color->blue);
 	/* If a tag by this name already exists, re-use it. */
 	ttab = gtk_text_buffer_get_tag_table(GTK_TEXT_BUFFER(txi->buffer));
-	if((tag = gtk_text_tag_table_lookup(ttab, tname)) == NULL) 
+	if((tag = gtk_text_tag_table_lookup(ttab, tname)) == NULL)
 		tag = gtk_text_buffer_create_tag(GTK_TEXT_BUFFER(txi->buffer), tname, "foreground-gdk", color, NULL);
 	gtk_text_buffer_apply_tag(GTK_TEXT_BUFFER(txi->buffer), tag, &start, &end);
 }
@@ -220,7 +221,7 @@ gint txv_text_load(GtkWidget *wid, const gchar *name, gboolean use_mmap, gsize b
 	if((wid == NULL) || ((txi = gtk_object_get_user_data(GTK_OBJECT(wid))) == NULL) || (name == NULL))
 		return 0;
 
-	txv_set_label(wid, name);
+	txv_set_label_from_filename(wid, name);
 
 	err_clear(txi->min);
 	if((fd = open(name, O_RDONLY)) >= 0)
@@ -305,7 +306,7 @@ gint txv_text_load_hex(GtkWidget *win, const gchar *name)
 	if((win == NULL) || ((txi = gtk_object_get_user_data(GTK_OBJECT(win))) == NULL) || (name == NULL))
 		return 0;
 
-	txv_set_label(win, name);
+	txv_set_label_from_filename(win, name);
 
 	memset(group, ' ', sizeof group - 1);
 	group[sizeof group - 1] = '\0';
@@ -313,7 +314,6 @@ gint txv_text_load_hex(GtkWidget *win, const gchar *name)
 	text[sizeof text - 1]   = '\0';
 
 	err_clear(txi->min);
-/*	gtk_text_freeze(GTK_TEXT(txi->text));*/
 	if((fd = open(name, O_RDONLY)) >= 0)
 	{
 		GtkTextIter	iter;
@@ -334,7 +334,6 @@ gint txv_text_load_hex(GtkWidget *win, const gchar *name)
 		}
 		close(fd);
 	}
-/*	gtk_text_thaw(GTK_TEXT(txi->text));*/
 
 /*	if((tag = gtk_text_tag_new("fixed")) != NULL)
 	{
@@ -413,7 +412,7 @@ static gint evt_pos_changed(GtkAdjustment *adj, gpointer user)
 	}
 	else
 		p = 0.0f;
-	
+
 	gtk_text_view_window_to_buffer_coords(GTK_TEXT_VIEW(txi->text), GTK_TEXT_WINDOW_WIDGET, 0, 0, &bx, &by);
 	gtk_text_view_get_line_at_y(GTK_TEXT_VIEW(txi->text), &iter, by, NULL);
 	by = gtk_text_iter_get_line(&iter) + 1;
@@ -587,7 +586,7 @@ static gboolean do_search(TxvInfo *txi, const gchar *re_src, gboolean nocase, gb
 					show_text(txi, txi->search_pos + startpos);
 					gtk_text_buffer_get_iter_at_offset(GTK_TEXT_BUFFER(txi->buffer), &start, txi->search_pos + startpos);
 					gtk_text_buffer_get_iter_at_offset(GTK_TEXT_BUFFER(txi->buffer), &end, txi->search_pos + endpos);
-					gtk_text_buffer_select_range(GTK_TEXT_BUFFER(txi->buffer), &start, &end); 
+					gtk_text_buffer_select_range(GTK_TEXT_BUFFER(txi->buffer), &start, &end);
 					txi->search_pos += endpos;
 				}
 				found = TRUE;
@@ -730,7 +729,7 @@ GtkWidget * txv_open(MainInfo *min, const gchar *label)
 	txi->bplabel = gtk_label_new("");
 	gtk_misc_set_alignment(GTK_MISC(txi->bplabel), 1.0f, 0.5f);
 	gtk_box_pack_start(GTK_BOX(txi->bhbox), txi->bplabel, FALSE, FALSE, 0);
-	
+
 	accel = gtk_accel_group_new();
 
 	btn = gtk_button_new_from_stock(GTK_STOCK_GO_UP);
@@ -825,6 +824,17 @@ void txv_set_label(GtkWidget *wid, const gchar *text)
 	}
 }
 
+/* 2009-05-27 -	Set the label of the view, based on a filename input. This needs encoding-conversion. */
+void txv_set_label_from_filename(GtkWidget *wid, const gchar *filename)
+{
+	Conv	conv;
+	gchar	*dpl;
+
+	dpl = conv_begin_reverse(&conv, filename);
+	txv_set_label(wid, dpl);
+	conv_end(&conv);
+}
+
 /* 1999-03-02 -	Enable the text widget for viewing. Called once all insertions are done. */
 void txv_enable(GtkWidget *wid)
 {
