@@ -626,7 +626,7 @@ GtkWidget * win_window_open(const WinInfo *wi, guint32 id)
 			gtk_window_set_position(GTK_WINDOW(wid), GTK_WIN_POS_MOUSE);
 		gtk_widget_realize(wid);
 		if(wi->min->gui != NULL && id != WIN_MAIN)
-			gtk_window_set_transient_for(wid, wi->min->gui->window);
+			gtk_window_set_transient_for(GTK_WINDOW(wid), GTK_WINDOW(wi->min->gui->window));
 		if(wd->title != NULL)
 			win_window_set_title(wid, wd->title);
 		errno = old_errno;
