@@ -43,6 +43,9 @@ extern GtkWidget *	win_wininfo_build(const WinInfo *wi, gboolean *modified);
 extern void		win_wininfo_save(const WinInfo *wi, FILE *out);
 extern void		win_wininfo_load(WinInfo *wi, const XmlNode *node);
 
+extern void		win_borders_set(WinInfo *, gint width, gint height);
+extern void		win_borders_get(const WinInfo *, gint *width, gint *height);
+
 extern void		win_window_new(WinInfo *wi, guint32 id, WinType type, gboolean persistent, const gchar *title, const gchar *label);
 extern void		win_window_pos_grab_set(const WinInfo *wi, guint32 id, gboolean grab);
 extern void		win_window_pos_set(const WinInfo *wi, guint32 id, gint x, gint y);
